import { IgrToolAction } from "./igr-tool-action";
import { ToolActionRadio } from "./ToolActionRadio";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
export class IgrToolActionRadio extends IgrToolAction {
    createImplementation() {
        return new ToolActionRadio();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the channel this radio button belongs to.
    */
    get channel() {
        return this.i.hk;
    }
    set channel(v) {
        this.i.hk = v;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get isChecked() {
        return this.i.hd;
    }
    set isChecked(v) {
        this.i.hd = ensureBool(v);
    }
    /**
     * Gets or sets if the checked state of the radio is handled manually by the user. The radio
     * well not become selected when clicked if this property is true.
    */
    get isManual() {
        return this.i.he;
    }
    set isManual(v) {
        this.i.he = ensureBool(v);
    }
    /**
     * Gets or sets the background color of the radio when in the unchecked state.
    */
    get uncheckedBackgroundColor() {
        return brushToString(this.i.h8);
    }
    set uncheckedBackgroundColor(v) {
        this.i.h8 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the radio when in the unchecked state.
    */
    get actualUncheckedBackgroundColor() {
        return brushToString(this.i.h4);
    }
    set actualUncheckedBackgroundColor(v) {
        this.i.h4 = stringToBrush(v);
    }
    /**
     * Gets or sets the background color of the radio when in the checked state.
    */
    get checkedBackgroundColor() {
        return brushToString(this.i.h6);
    }
    set checkedBackgroundColor(v) {
        this.i.h6 = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the radio when in the checked state.
    */
    get actualCheckedBackgroundColor() {
        return brushToString(this.i.h2);
    }
    set actualCheckedBackgroundColor(v) {
        this.i.h2 = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the radio when in the unchecked state.
    */
    get uncheckedBorderColor() {
        return brushToString(this.i.h9);
    }
    set uncheckedBorderColor(v) {
        this.i.h9 = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the radio when in the unchecked state.
    */
    get actualUncheckedBorderColor() {
        return brushToString(this.i.h5);
    }
    set actualUncheckedBorderColor(v) {
        this.i.h5 = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the radio when in the checked state.
    */
    get checkedBorderColor() {
        return brushToString(this.i.h7);
    }
    set checkedBorderColor(v) {
        this.i.h7 = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the radio when in the checked state.
    */
    get actualCheckedBorderColor() {
        return brushToString(this.i.h3);
    }
    set actualCheckedBorderColor(v) {
        this.i.h3 = stringToBrush(v);
    }
}
