import * as React from 'react';
import { fromSize, ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter } from "igniteui-react-core";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
import { ToolPanel } from './ToolPanel';
import { BaseControlTheme_$type } from "igniteui-react-core";
import { ToolPanelOrientation_$type } from './ToolPanelOrientation';
import { ToolAction } from "./ToolAction";
import { IgrToolActionCollection } from "./igr-tool-action-collection";
import { IgrToolPanelContentRefreshedEventArgs } from "./igr-tool-panel-content-refreshed-event-args";
import { IgrToolCommandEventArgs } from './igr-tool-command-event-args';
import { NestedActionMode_$type } from './NestedActionMode';
export class IgrToolPanel extends React.Component {
    set height(value) {
        this._height = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get width() {
        return this._width;
    }
    _getMainRef(ref) {
        this._elRef = ref;
        this.verifyReferences();
    }
    _updateContentChildren() {
        this.contentActions.length = 0;
        let contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        for (let i = 0; i < contentChildrenActual.length; i++) {
            if ((ToolAction.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentActions.push(contentChildrenActual[i]);
            }
        }
        if (this._actionsAdapter !== null) {
            this._actionsAdapter.notifyContentChanged();
        }
    }
    /**
     * A collection of manually added style mappings for the treemap.
    */
    get actions() {
        if (this._actions === null) {
            let coll = new IgrToolActionCollection();
            let inner = coll._innerColl;
            inner.addListener((sender, e) => {
                switch (e.action) {
                    case NotifyCollectionChangedAction.Add:
                        this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Remove:
                        this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                        break;
                    case NotifyCollectionChangedAction.Replace:
                        this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                        this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                        break;
                    case NotifyCollectionChangedAction.Reset:
                        this._actionsAdapter.clearManualItems();
                        break;
                }
            });
            this._actions = coll;
        }
        return this._actions;
    }
    render() {
        let children = this._contentChildrenManager.getChildren(this.props.children);
        if (this._portalManager)
            this._portalManager.onRender(children);
        let div = React.createElement("div", {
            ref: this._getMainRef,
            className: "ig-tool-panel igr-tool-panel",
            children: children
        });
        return div;
    }
    verifyReferences() {
        if (this._elRef) {
            this.requestRender = this.requestRender.bind(this);
            this._portalManager = new PortalManager("toolPanelContent", this.requestRender);
            this._reactRenderer = new ReactRenderer(this._elRef, document, true, {}, this._portalManager);
            if (document) {
                this._elRef.style.display = "block";
                this._elRef.style.width = "100%";
                this._elRef.style.height = "100%";
            }
            // render needs to fire again after the portalManager is created. 
            this.requestRender();
            this.i.provideContainer(this._reactRenderer);
            this.i.notifySizeChanged();
            this._reactRenderer.addSizeWatcher(() => {
                this.i.notifySizeChanged();
            });
        }
    }
    requestRender() {
        if (this._initialized)
            this.setState({});
    }
    constructor(props) {
        super(props);
        this._implementation = null;
        this._reactRenderer = null;
        this.contentActions = [];
        /**
        * The style mappings actually present in the treemap. Do not directly modify this array.
        * This array's contents can be modified by causing React to reproject the child content.
        * Or adding and removing ranges from the manual ranges collection on the ranges property.
        */
        this.actualActions = [];
        this._actions = null;
        this._actionsAdapter = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._contentRefreshed = null;
        this._contentRefreshed_wrapped = null;
        this._onCommand = null;
        this._onCommand_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._getMainRef = this._getMainRef.bind(this);
        this._contentChildrenManager = new ContentChildrenManager((ch) => ch.key || ch.props.name, (ch) => ch.key || ch.props.name, () => this._updateContentChildren());
        this._actionsAdapter = new CollectionAdapter(this.contentActions, this.i.actions, this.actualActions, (c) => c.i, (i) => {
            if (this._reactRenderer && this._elRef) {
                i._styling(this._elRef, this, this);
            }
        }, (i) => { });
        //var multiColumnComboBox = this.i;
        //multiColumnComboBox.notifySizeChanged();
        if (props) {
            this.initializeProperties();
        }
        this._initialized = true;
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    componentWillUnmount() {
        this.i.destroy();
        if (this._reactRenderer)
            this._reactRenderer.destroy();
    }
    componentDidMount() {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this.i.notifySizeChanged();
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._elRef, this);
        if (this.actualActions && this.actualActions.length > 0) {
            var currProperty = this.actualActions;
            for (var i = 0; i < currProperty.length; i++) {
                currProperty[i]._styling(this._elRef, this, this);
            }
        }
        this.updateStyle();
        this.i.notifySizeChanged();
    }
    createImplementation() {
        return new ToolPanel();
    }
    get i() {
        return this._implementation;
    }
    /**
 * Gets or sets if the tool actions should display their submenus on mouse hover.
*/
    get showOnHover() {
        return this.i.al;
    }
    set showOnHover(v) {
        this.i.al = ensureBool(v);
    }
    /**
     * Gets or sets the text style for the panel.
    */
    get cellTextStyle() {
        if (this.i.ab == null) {
            return null;
        }
        return this.i.ab.fontString;
    }
    set cellTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ab = fi;
    }
    /**
     * Gets or sets the subtitle text style for the panel.
    */
    get subtitleTextStyle() {
        if (this.i.ad == null) {
            return null;
        }
        return this.i.ad.fontString;
    }
    set subtitleTextStyle(v) {
        let fi = new FontInfo();
        fi.fontString = v;
        this.i.ad = fi;
    }
    /**
     * Gets or sets the base built in theme to use for the checkbox.
    */
    get baseTheme() {
        return this.i.u;
    }
    set baseTheme(v) {
        this.i.u = ensureEnum(BaseControlTheme_$type, v);
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get backgroundColor() {
        return brushToString(this.i.ha);
    }
    set backgroundColor(v) {
        this.i.ha = stringToBrush(v);
    }
    get actualBackgroundColor() {
        return brushToString(this.i.gp);
    }
    set actualBackgroundColor(v) {
        this.i.gp = stringToBrush(v);
    }
    /**
     * Gets or sets the background color for submenus.
    */
    get submenuBackgroundColor() {
        return brushToString(this.i.ho);
    }
    set submenuBackgroundColor(v) {
        this.i.ho = stringToBrush(v);
    }
    get actualSubmenuBackgroundColor() {
        return brushToString(this.i.g3);
    }
    set actualSubmenuBackgroundColor(v) {
        this.i.g3 = stringToBrush(v);
    }
    /**
     * Gets or sets the group header background color.
    */
    get groupHeaderBackgroundColor() {
        return brushToString(this.i.he);
    }
    set groupHeaderBackgroundColor(v) {
        this.i.he = stringToBrush(v);
    }
    get actualGroupHeaderBackgroundColor() {
        return brushToString(this.i.gt);
    }
    set actualGroupHeaderBackgroundColor(v) {
        this.i.gt = stringToBrush(v);
    }
    /**
     * Gets or sets the separator background color.
    */
    get separatorBackgroundColor() {
        return brushToString(this.i.hn);
    }
    set separatorBackgroundColor(v) {
        this.i.hn = stringToBrush(v);
    }
    get actualSeparatorBackgroundColor() {
        return brushToString(this.i.g2);
    }
    set actualSeparatorBackgroundColor(v) {
        this.i.g2 = stringToBrush(v);
    }
    /**
     * Gets or sets the group header separator background color.
    */
    get groupHeaderSeparatorBackgroundColor() {
        return brushToString(this.i.hf);
    }
    set groupHeaderSeparatorBackgroundColor(v) {
        this.i.hf = stringToBrush(v);
    }
    get actualGroupHeaderSeparatorBackgroundColor() {
        return brushToString(this.i.gu);
    }
    set actualGroupHeaderSeparatorBackgroundColor(v) {
        this.i.gu = stringToBrush(v);
    }
    /**
     * Gets or sets the hover background color.
    */
    get hoverBackgroundColor() {
        return brushToString(this.i.hj);
    }
    set hoverBackgroundColor(v) {
        this.i.hj = stringToBrush(v);
    }
    get actualHoverBackgroundColor() {
        return brushToString(this.i.gy);
    }
    set actualHoverBackgroundColor(v) {
        this.i.gy = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the text of the component.
    */
    get textColor() {
        return brushToString(this.i.hq);
    }
    set textColor(v) {
        this.i.hq = stringToBrush(v);
    }
    get actualTextColor() {
        return brushToString(this.i.g5);
    }
    set actualTextColor(v) {
        this.i.g5 = stringToBrush(v);
    }
    get actualSubtitleTextColor() {
        return brushToString(this.i.g4);
    }
    set actualSubtitleTextColor(v) {
        this.i.g4 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the subtitle of the component.
    */
    get subtitleTextColor() {
        return brushToString(this.i.hp);
    }
    set subtitleTextColor(v) {
        this.i.hp = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the text in disabled tool actions.
    */
    get disabledTextColor() {
        return brushToString(this.i.hd);
    }
    set disabledTextColor(v) {
        this.i.hd = stringToBrush(v);
    }
    get actualDisabledTextColor() {
        return brushToString(this.i.gs);
    }
    set actualDisabledTextColor(v) {
        this.i.gs = stringToBrush(v);
    }
    /**
     * Gets or sets the text color for group header tool actions.
    */
    get groupHeaderTextColor() {
        return brushToString(this.i.hh);
    }
    set groupHeaderTextColor(v) {
        this.i.hh = stringToBrush(v);
    }
    get actualGroupHeaderTextColor() {
        return brushToString(this.i.gw);
    }
    set actualGroupHeaderTextColor(v) {
        this.i.gw = stringToBrush(v);
    }
    /**
     * Gets or sets the text color for group header subtitle.
    */
    get groupHeaderSubtitleTextColor() {
        return brushToString(this.i.hg);
    }
    set groupHeaderSubtitleTextColor(v) {
        this.i.hg = stringToBrush(v);
    }
    get actualGroupHeaderSubtitleTextColor() {
        return brushToString(this.i.gv);
    }
    set actualGroupHeaderSubtitleTextColor(v) {
        this.i.gv = stringToBrush(v);
    }
    /**
     * Gets or sets the tooltip text color.
    */
    get toolTipTextColor() {
        return brushToString(this.i.hs);
    }
    set toolTipTextColor(v) {
        this.i.hs = stringToBrush(v);
    }
    get actualToolTipTextColor() {
        return brushToString(this.i.g7);
    }
    set actualToolTipTextColor(v) {
        this.i.g7 = stringToBrush(v);
    }
    /**
     * Gets or sets the tooltip background color.
    */
    get toolTipBackgroundColor() {
        return brushToString(this.i.hr);
    }
    set toolTipBackgroundColor(v) {
        this.i.hr = stringToBrush(v);
    }
    /**
     * Gets the actual tooltip background color.
    */
    get actualToolTipBackgroundColor() {
        return brushToString(this.i.g6);
    }
    set actualToolTipBackgroundColor(v) {
        this.i.g6 = stringToBrush(v);
    }
    /**
     * Gets or sets the tooltip corner radius.
    */
    get toolTipCornerRadius() {
        return this.i.b2;
    }
    set toolTipCornerRadius(v) {
        this.i.b2 = +v;
    }
    /**
     * Gets the actual tooltip corner radius.
    */
    get actualToolTipCornerRadius() {
        return this.i.bq;
    }
    set actualToolTipCornerRadius(v) {
        this.i.bq = +v;
    }
    /**
     * Gets or sets the shadow elevation for the tooltip.
    */
    get toolTipElevation() {
        return this.i.b3;
    }
    set toolTipElevation(v) {
        this.i.b3 = +v;
    }
    /**
     * Gets the actual shadow elevation used by the tooltip.
    */
    get actualToolTipElevation() {
        return this.i.br;
    }
    set actualToolTipElevation(v) {
        this.i.br = +v;
    }
    /**
     * Gets or sets the fill color of icons in the ToolPanel.
    */
    get iconFill() {
        return brushToString(this.i.hk);
    }
    set iconFill(v) {
        this.i.hk = stringToBrush(v);
    }
    /**
     * Gets the actual icon fill color.
    */
    get actualIconFill() {
        return brushToString(this.i.gz);
    }
    set actualIconFill(v) {
        this.i.gz = stringToBrush(v);
    }
    /**
     * Gets or sets the stroke color of icons in the ToolPanel.
    */
    get iconStroke() {
        return brushToString(this.i.hl);
    }
    set iconStroke(v) {
        this.i.hl = stringToBrush(v);
    }
    /**
     * Gets the actual icon stroke color.
    */
    get actualIconStroke() {
        return brushToString(this.i.g0);
    }
    set actualIconStroke(v) {
        this.i.g0 = stringToBrush(v);
    }
    /**
     * Gets or sets the left padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingLeft() {
        return this.i.bz;
    }
    set separatorVerticalPaddingLeft(v) {
        this.i.bz = +v;
    }
    get actualSeparatorVerticalPaddingLeft() {
        return this.i.bn;
    }
    set actualSeparatorVerticalPaddingLeft(v) {
        this.i.bn = +v;
    }
    /**
     * Gets or sets the right padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingRight() {
        return this.i.b0;
    }
    set separatorVerticalPaddingRight(v) {
        this.i.b0 = +v;
    }
    get actualSeparatorVerticalPaddingRight() {
        return this.i.bo;
    }
    set actualSeparatorVerticalPaddingRight(v) {
        this.i.bo = +v;
    }
    /**
     * Gets or sets the top padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingTop() {
        return this.i.b1;
    }
    set separatorVerticalPaddingTop(v) {
        this.i.b1 = +v;
    }
    get actualSeparatorVerticalPaddingTop() {
        return this.i.bp;
    }
    set actualSeparatorVerticalPaddingTop(v) {
        this.i.bp = +v;
    }
    /**
     * Gets or sets the bottom padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingBottom() {
        return this.i.by;
    }
    set separatorVerticalPaddingBottom(v) {
        this.i.by = +v;
    }
    get actualSeparatorVerticalPaddingBottom() {
        return this.i.bm;
    }
    set actualSeparatorVerticalPaddingBottom(v) {
        this.i.bm = +v;
    }
    /**
     * Gets or sets the left padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingLeft() {
        return this.i.bv;
    }
    set separatorHorizontalPaddingLeft(v) {
        this.i.bv = +v;
    }
    get actualSeparatorHorizontalPaddingLeft() {
        return this.i.bj;
    }
    set actualSeparatorHorizontalPaddingLeft(v) {
        this.i.bj = +v;
    }
    /**
     * Gets or sets the right padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingRight() {
        return this.i.bw;
    }
    set separatorHorizontalPaddingRight(v) {
        this.i.bw = +v;
    }
    get actualSeparatorHorizontalPaddingRight() {
        return this.i.bk;
    }
    set actualSeparatorHorizontalPaddingRight(v) {
        this.i.bk = +v;
    }
    /**
     * Gets or sets the top padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingTop() {
        return this.i.bx;
    }
    set separatorHorizontalPaddingTop(v) {
        this.i.bx = +v;
    }
    get actualSeparatorHorizontalPaddingTop() {
        return this.i.bl;
    }
    set actualSeparatorHorizontalPaddingTop(v) {
        this.i.bl = +v;
    }
    /**
     * Gets or sets the bottom padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingBottom() {
        return this.i.bu;
    }
    set separatorHorizontalPaddingBottom(v) {
        this.i.bu = +v;
    }
    get actualSeparatorHorizontalPaddingBottom() {
        return this.i.bi;
    }
    set actualSeparatorHorizontalPaddingBottom(v) {
        this.i.bi = +v;
    }
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get orientation() {
        return this.i.r;
    }
    set orientation(v) {
        this.i.r = ensureEnum(ToolPanelOrientation_$type, v);
    }
    /**
     * Gets or sets the row height for the panel.
    */
    get rowHeight() {
        return this.i.b8;
    }
    set rowHeight(v) {
        this.i.b8 = +v;
    }
    /**
     * Gets the actual row height used by the panel.
    */
    get actualRowHeight() {
        return this.i.bh;
    }
    get highlightWidth() {
        return this.i.bt;
    }
    set highlightWidth(v) {
        this.i.bt = +v;
    }
    get actualHighlightWidth() {
        return this.i.bg;
    }
    set actualHighlightWidth(v) {
        this.i.bg = +v;
    }
    get highlightRadius() {
        return this.i.bs;
    }
    set highlightRadius(v) {
        this.i.bs = +v;
    }
    get actualHighlightRadius() {
        return this.i.bf;
    }
    set actualHighlightRadius(v) {
        this.i.bf = +v;
    }
    get highlightColor() {
        return brushToString(this.i.hi);
    }
    set highlightColor(v) {
        this.i.hi = stringToBrush(v);
    }
    get actualHighlightColor() {
        return brushToString(this.i.gx);
    }
    set actualHighlightColor(v) {
        this.i.gx = stringToBrush(v);
    }
    /**
     * Gets or sets the stroke color for all icon menu dropdown arrows.
    */
    get menuArrowStroke() {
        return brushToString(this.i.hm);
    }
    set menuArrowStroke(v) {
        this.i.hm = stringToBrush(v);
    }
    /**
     * Gets the actual stroke color for all icon menu dropdown arrows.
    */
    get actualMenuArrowStroke() {
        return brushToString(this.i.g1);
    }
    set actualMenuArrowStroke(v) {
        this.i.g1 = stringToBrush(v);
    }
    /**
     * Gets or sets the background color of the radio when in the unchecked state.
    */
    get uncheckedBackgroundColor() {
        return brushToString(this.i.ht);
    }
    set uncheckedBackgroundColor(v) {
        this.i.ht = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the radio when in the unchecked state.
    */
    get actualUncheckedBackgroundColor() {
        return brushToString(this.i.g8);
    }
    set actualUncheckedBackgroundColor(v) {
        this.i.g8 = stringToBrush(v);
    }
    /**
     * Gets or sets the background color of the radio when in the checked state.
    */
    get checkedBackgroundColor() {
        return brushToString(this.i.hb);
    }
    set checkedBackgroundColor(v) {
        this.i.hb = stringToBrush(v);
    }
    /**
     * Gets the actual background color of the radio when in the checked state.
    */
    get actualCheckedBackgroundColor() {
        return brushToString(this.i.gq);
    }
    set actualCheckedBackgroundColor(v) {
        this.i.gq = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the radio when in the unchecked state.
    */
    get uncheckedBorderColor() {
        return brushToString(this.i.hu);
    }
    set uncheckedBorderColor(v) {
        this.i.hu = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the radio when in the unchecked state.
    */
    get actualUncheckedBorderColor() {
        return brushToString(this.i.g9);
    }
    set actualUncheckedBorderColor(v) {
        this.i.g9 = stringToBrush(v);
    }
    /**
     * Gets or sets the border color of the radio when in the checked state.
    */
    get checkedBorderColor() {
        return brushToString(this.i.hc);
    }
    set checkedBorderColor(v) {
        this.i.hc = stringToBrush(v);
    }
    /**
     * Gets the actual border color of the radio when in the checked state.
    */
    get actualCheckedBorderColor() {
        return brushToString(this.i.gr);
    }
    set actualCheckedBorderColor(v) {
        this.i.gr = stringToBrush(v);
    }
    /**
     * Gets or sets the dropdown delay time in milliseconds.
    */
    get dropdownDelay() {
        return this.i.b7;
    }
    set dropdownDelay(v) {
        this.i.b7 = +v;
    }
    /**
     * Gets the actual dropdown delay.
    */
    get actualDropdownDelay() {
        return this.i.b6;
    }
    set actualDropdownDelay(v) {
        this.i.b6 = +v;
    }
    /**
     * Gets or sets the mode used when displaying nested actions.
    */
    get nestedActionMode() {
        return this.i.e;
    }
    set nestedActionMode(v) {
        this.i.e = ensureEnum(NestedActionMode_$type, v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.actions != null && this.actions.findByName && this.actions.findByName(name)) {
            return this.actions.findByName(name);
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("ToolPanel");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    refresh() {
        this.i.fb();
    }
    getDesiredSize() {
        let iv = this.i.hv();
        return fromSize(iv);
    }
    /**
     * Forces any open sub menus to close.
    
    */
    closeSubmenus() {
        this.i.er();
    }
    exportVisualData() {
        let iv = this.i.b9();
        return (iv);
    }
    exportSerializedVisualData() {
        let iv = this.i.dl();
        return (iv);
    }
    get contentRefreshed() {
        return this._contentRefreshed;
    }
    set contentRefreshed(ev) {
        if (this._contentRefreshed_wrapped !== null) {
            this.i.contentRefreshed = delegateRemove(this.i.contentRefreshed, this._contentRefreshed_wrapped);
            this._contentRefreshed_wrapped = null;
            this._contentRefreshed = null;
        }
        this._contentRefreshed = ev;
        this._contentRefreshed_wrapped = (o, e) => {
            let outerArgs = new IgrToolPanelContentRefreshedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeContentRefreshed) {
                this.beforeContentRefreshed(this, outerArgs);
            }
            if (this._contentRefreshed) {
                this._contentRefreshed(this, outerArgs);
            }
        };
        this.i.contentRefreshed = delegateCombine(this.i.contentRefreshed, this._contentRefreshed_wrapped);
        ;
    }
    get onCommand() {
        return this._onCommand;
    }
    set onCommand(ev) {
        if (this._onCommand_wrapped !== null) {
            this.i.onCommand = delegateRemove(this.i.onCommand, this._onCommand_wrapped);
            this._onCommand_wrapped = null;
            this._onCommand = null;
        }
        this._onCommand = ev;
        this._onCommand_wrapped = (o, e) => {
            let outerArgs = new IgrToolCommandEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOnCommand) {
                this.beforeOnCommand(this, outerArgs);
            }
            if (this._onCommand) {
                this._onCommand(this, outerArgs);
            }
        };
        this.i.onCommand = delegateCombine(this.i.onCommand, this._onCommand_wrapped);
        ;
    }
}
