import * as React from 'react';
import { brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { XExpansionPanel } from './XExpansionPanel';
import { IgrOnExpandedEventArgs } from './igr-on-expanded-event-args';
import { IgrOnCollapsedEventArgs } from './igr-on-collapsed-event-args';
export class IgrXExpansionPanel extends React.Component {
    set height(value) {
        this._height = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        if (this._elRef) {
            this._elRef.style.height = value;
            this.i.notifySizeChanged();
        }
    }
    get width() {
        return this._width;
    }
    _getMainRef(ref) {
        this._elRef = ref;
        this.verifyReferences();
    }
    _getHeaderRef(ref) {
        this._headerRef = ref;
        this.verifyReferences();
    }
    _getContentAreaOuterRef(ref) {
        this._contentAreaOuterRef = ref;
        this.verifyReferences();
    }
    _getContentAreaInnerRef(ref) {
        this._contentAreaInnerRef = ref;
        this.verifyReferences();
    }
    verifyReferences() {
        if (this._elRef &&
            this._headerRef &&
            this._contentAreaOuterRef &&
            this._contentAreaInnerRef) {
            this.requestRender = this.requestRender.bind(this);
            this._portalManager = new PortalManager("iconContent", this.requestRender);
            var ren = new ReactRenderer(this._elRef, document, true, {}, this._portalManager);
            // render needs to fire again after the portalManager is created. 
            this.requestRender();
            this._reactRenderer = ren;
            this.i.provideRenderer(this._reactRenderer);
            var headerWrapper = this._reactRenderer.getWrapper(this._headerRef);
            this.i.provideHeader(headerWrapper);
            var contentOuterWrapper = this._reactRenderer.getWrapper(this._contentAreaOuterRef);
            this.i.provideContentAreaOuter(contentOuterWrapper);
            var contentInnerWrapper = this._reactRenderer.getWrapper(this._contentAreaInnerRef);
            this.i.provideContentAreaInner(contentInnerWrapper);
        }
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        let divChildren = [];
        let header = React.createElement("div", {
            key: 'expansionPanelHeaderArea',
            ref: this._getHeaderRef
        });
        let contentInner = React.createElement("div", {
            key: 'expansionPanelContentAreaInner',
            ref: this._getContentAreaInnerRef,
            children: children,
        });
        let contentOuter = React.createElement("div", {
            key: 'expansionPanelContentAreaOuter',
            ref: this._getContentAreaOuterRef,
            children: contentInner
        });
        divChildren.push(header);
        divChildren.push(contentOuter);
        if (this._portalManager)
            this._portalManager.onRender(divChildren);
        let div = React.createElement("div", {
            ref: this._getMainRef,
            className: "ig-expansion-panel igr-expansion-panel",
            children: divChildren
        });
        return div;
    }
    requestRender() {
        if (this._initialized)
            this.setState({});
    }
    constructor(props) {
        super(props);
        this._reactRenderer = null;
        this._implementation = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._onCollapsed = null;
        this._onCollapsed_wrapped = null;
        this._onExpanded = null;
        this._onExpanded_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._getMainRef = this._getMainRef.bind(this);
        this._getHeaderRef = this._getHeaderRef.bind(this);
        this._getContentAreaOuterRef = this._getContentAreaOuterRef.bind(this);
        this._getContentAreaInnerRef = this._getContentAreaInnerRef.bind(this);
        if (props) {
            this.initializeProperties();
        }
        this._initialized = true;
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    initializeProperties() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    // supports angular themes or custom properties set in CSS
    updateStyle() {
        this._styling(this._elRef, this);
    }
    destroy() {
        this.i.destroy();
        if (this._reactRenderer)
            this._reactRenderer.destroy();
    }
    componentWillUnmount() {
    }
    componentDidMount() {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this.initializeContent();
    }
    initializeContent() {
        this._styling(this._elRef, this);
        this.updateStyle();
    }
    createImplementation() {
        return new XExpansionPanel();
    }
    get i() {
        return this._implementation;
    }
    /**
 * Gets / sets the caption to display in the header area.
*/
    get caption() {
        return this.i.ab;
    }
    set caption(v) {
        this.i.ab = v;
    }
    /**
     * Gets or sets the color to use for the header caption text.
    */
    get captionTextColor() {
        return brushToString(this.i.bq);
    }
    set captionTextColor(v) {
        this.i.bq = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the actual header caption text.
    */
    get actualCaptionTextColor() {
        return brushToString(this.i.bj);
    }
    set actualCaptionTextColor(v) {
        this.i.bj = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the header caption text when the panel is collapsed.
    */
    get captionCollapsedTextColor() {
        return brushToString(this.i.bo);
    }
    set captionCollapsedTextColor(v) {
        this.i.bo = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the header caption text when the panel is expanded.
    */
    get captionExpandedTextColor() {
        return brushToString(this.i.bp);
    }
    set captionExpandedTextColor(v) {
        this.i.bp = stringToBrush(v);
    }
    /**
     * Gets / sets the description to display in the header area.
    */
    get description() {
        return this.i.ah;
    }
    set description(v) {
        this.i.ah = v;
    }
    /**
     * Gets or sets the color to use for the header description text.
    */
    get descriptionTextColor() {
        return brushToString(this.i.bz);
    }
    set descriptionTextColor(v) {
        this.i.bz = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the actual header description text.
    */
    get actualDescriptionTextColor() {
        return brushToString(this.i.bk);
    }
    set actualDescriptionTextColor(v) {
        this.i.bk = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the header description text when the panel is collapsed.
    */
    get descriptionCollapsedTextColor() {
        return brushToString(this.i.bx);
    }
    set descriptionCollapsedTextColor(v) {
        this.i.bx = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the header description text when the panel is expanded.
    */
    get descriptionExpandedTextColor() {
        return brushToString(this.i.by);
    }
    set descriptionExpandedTextColor(v) {
        this.i.by = stringToBrush(v);
    }
    /**
     * Gets or sets the elevation to use for the button regardless of type.
    */
    get elevation() {
        return this.i.s;
    }
    set elevation(v) {
        this.i.s = +v;
    }
    /**
     * Gets or sets the elevation of the border shadow
    */
    get actualElevation() {
        return this.i.q;
    }
    set actualElevation(v) {
        this.i.q = +v;
    }
    /**
     * Gets / sets the expanded state of the panel.
    */
    get expanded() {
        return this.i.n;
    }
    set expanded(v) {
        this.i.n = ensureBool(v);
    }
    /**
     * Gets or sets the color to use for the background of the header.
    */
    get headerBackgroundColor() {
        return brushToString(this.i.b6);
    }
    set headerBackgroundColor(v) {
        this.i.b6 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the actual background of the header.
    */
    get actualHeaderBackgroundColor() {
        return brushToString(this.i.bl);
    }
    set actualHeaderBackgroundColor(v) {
        this.i.bl = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the background of the header when the panel is expanded.
    */
    get headerCollapsedBackgroundColor() {
        return brushToString(this.i.b7);
    }
    set headerCollapsedBackgroundColor(v) {
        this.i.b7 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the background of the header when the panel is expanded.
    */
    get headerExpandedBackgroundColor() {
        return brushToString(this.i.b8);
    }
    set headerExpandedBackgroundColor(v) {
        this.i.b8 = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    get actualUmbraShadowColor() {
        return brushToString(this.i.bn);
    }
    set actualUmbraShadowColor(v) {
        this.i.bn = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    get actualPenumbraShadowColor() {
        return brushToString(this.i.bm);
    }
    set actualPenumbraShadowColor(v) {
        this.i.bm = stringToBrush(v);
    }
    /**
     * Gets or sets the color to use for the check mark when the checkbox is checked.
    */
    get actualAmbientShadowColor() {
        return brushToString(this.i.bi);
    }
    set actualAmbientShadowColor(v) {
        this.i.bi = stringToBrush(v);
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("XExpansionPanel");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    /**
 * Collapses the contents of the expansion panel.

*/
    collapse() {
        this.i.ar();
    }
    /**
     * Expands the contents of the expansion panel.
    
    */
    expand() {
        this.i.au();
    }
    /**
     * Toggles the expanded state of the expansion panel.
    
    */
    toggle() {
        this.i.a2();
    }
    /**
     * Fires when the expansion panel is collapsed.
    */
    get onCollapsed() {
        return this._onCollapsed;
    }
    set onCollapsed(ev) {
        if (this._onCollapsed_wrapped !== null) {
            this.i.onCollapsed = delegateRemove(this.i.onCollapsed, this._onCollapsed_wrapped);
            this._onCollapsed_wrapped = null;
            this._onCollapsed = null;
        }
        this._onCollapsed = ev;
        this._onCollapsed_wrapped = (o, e) => {
            let outerArgs = new IgrOnCollapsedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOnCollapsed) {
                this.beforeOnCollapsed(this, outerArgs);
            }
            if (this._onCollapsed) {
                this._onCollapsed(this, outerArgs);
            }
        };
        this.i.onCollapsed = delegateCombine(this.i.onCollapsed, this._onCollapsed_wrapped);
        ;
    }
    get onExpanded() {
        return this._onExpanded;
    }
    set onExpanded(ev) {
        if (this._onExpanded_wrapped !== null) {
            this.i.onExpanded = delegateRemove(this.i.onExpanded, this._onExpanded_wrapped);
            this._onExpanded_wrapped = null;
            this._onExpanded = null;
        }
        this._onExpanded = ev;
        this._onExpanded_wrapped = (o, e) => {
            let outerArgs = new IgrOnExpandedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeOnExpanded) {
                this.beforeOnExpanded(this, outerArgs);
            }
            if (this._onExpanded) {
                this._onExpanded(this, outerArgs);
            }
        };
        this.i.onExpanded = delegateCombine(this.i.onExpanded, this._onExpanded_wrapped);
        ;
    }
}
