import { __extends, __values } from "tslib";
import * as React from 'react';
import { fromSize, ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter } from "igniteui-react-core";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
import { ToolPanel } from './ToolPanel';
import { BaseControlTheme_$type } from "igniteui-react-core";
import { ToolPanelOrientation_$type } from './ToolPanelOrientation';
import { ToolAction } from "./ToolAction";
import { IgrToolActionCollection } from "./igr-tool-action-collection";
import { IgrToolPanelContentRefreshedEventArgs } from "./igr-tool-panel-content-refreshed-event-args";
import { IgrToolCommandEventArgs } from './igr-tool-command-event-args';
import { NestedActionMode_$type } from './NestedActionMode';
var IgrToolPanel = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolPanel, _super);
    function IgrToolPanel(props) {
        var _this = _super.call(this, props) || this;
        _this._implementation = null;
        _this._reactRenderer = null;
        _this.contentActions = [];
        /**
        * The style mappings actually present in the treemap. Do not directly modify this array.
        * This array's contents can be modified by causing React to reproject the child content.
        * Or adding and removing ranges from the manual ranges collection on the ranges property.
        */
        _this.actualActions = [];
        _this._actions = null;
        _this._actionsAdapter = null;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        _this._contentRefreshed = null;
        _this._contentRefreshed_wrapped = null;
        _this._onCommand = null;
        _this._onCommand_wrapped = null;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._implementation = _this.createImplementation();
        _this._getMainRef = _this._getMainRef.bind(_this);
        _this._contentChildrenManager = new ContentChildrenManager(function (ch) { return ch.key || ch.props.name; }, function (ch) { return ch.key || ch.props.name; }, function () { return _this._updateContentChildren(); });
        _this._actionsAdapter = new CollectionAdapter(_this.contentActions, _this.i.actions, _this.actualActions, function (c) { return c.i; }, function (i) {
            if (_this._reactRenderer && _this._elRef) {
                i._styling(_this._elRef, _this, _this);
            }
        }, function (i) { });
        //var multiColumnComboBox = this.i;
        //multiColumnComboBox.notifySizeChanged();
        if (props) {
            _this.initializeProperties();
        }
        _this._initialized = true;
        return _this;
    }
    Object.defineProperty(IgrToolPanel.prototype, "height", {
        get: function () {
            return this._height;
        },
        set: function (value) {
            this._height = value;
            if (this._elRef) {
                this._elRef.style.height = value;
                this.i.notifySizeChanged();
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "width", {
        get: function () {
            return this._width;
        },
        set: function (value) {
            this._width = value;
            if (this._elRef) {
                this._elRef.style.height = value;
                this.i.notifySizeChanged();
            }
        },
        enumerable: false,
        configurable: true
    });
    IgrToolPanel.prototype._getMainRef = function (ref) {
        this._elRef = ref;
        this.verifyReferences();
    };
    IgrToolPanel.prototype._updateContentChildren = function () {
        this.contentActions.length = 0;
        var contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((ToolAction.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentActions.push(contentChildrenActual[i]);
            }
        }
        if (this._actionsAdapter !== null) {
            this._actionsAdapter.notifyContentChanged();
        }
    };
    Object.defineProperty(IgrToolPanel.prototype, "actions", {
        /**
         * A collection of manually added style mappings for the treemap.
        */
        get: function () {
            var _this = this;
            if (this._actions === null) {
                var coll = new IgrToolActionCollection();
                var inner = coll._innerColl;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._actionsAdapter.clearManualItems();
                            break;
                    }
                });
                this._actions = coll;
            }
            return this._actions;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolPanel.prototype.render = function () {
        var children = this._contentChildrenManager.getChildren(this.props.children);
        if (this._portalManager)
            this._portalManager.onRender(children);
        var div = React.createElement("div", {
            ref: this._getMainRef,
            className: "ig-tool-panel igr-tool-panel",
            children: children
        });
        return div;
    };
    IgrToolPanel.prototype.verifyReferences = function () {
        var _this = this;
        if (this._elRef) {
            this.requestRender = this.requestRender.bind(this);
            this._portalManager = new PortalManager("toolPanelContent", this.requestRender);
            this._reactRenderer = new ReactRenderer(this._elRef, document, true, {}, this._portalManager);
            if (document) {
                this._elRef.style.display = "block";
                this._elRef.style.width = "100%";
                this._elRef.style.height = "100%";
            }
            // render needs to fire again after the portalManager is created. 
            this.requestRender();
            this.i.provideContainer(this._reactRenderer);
            this.i.notifySizeChanged();
            this._reactRenderer.addSizeWatcher(function () {
                _this.i.notifySizeChanged();
            });
        }
    };
    IgrToolPanel.prototype.requestRender = function () {
        if (this._initialized)
            this.setState({});
    };
    IgrToolPanel.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_1, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        return true;
    };
    IgrToolPanel.prototype.initializeProperties = function () {
        var e_2, _a;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
    };
    // supports angular themes or custom properties set in CSS
    IgrToolPanel.prototype.updateStyle = function () {
        this._styling(this._elRef, this);
    };
    IgrToolPanel.prototype.componentWillUnmount = function () {
        this.i.destroy();
        if (this._reactRenderer)
            this._reactRenderer.destroy();
    };
    IgrToolPanel.prototype.componentDidMount = function () {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this.i.notifySizeChanged();
        this.initializeContent();
    };
    IgrToolPanel.prototype.initializeContent = function () {
        this._styling(this._elRef, this);
        if (this.actualActions && this.actualActions.length > 0) {
            var currProperty = this.actualActions;
            for (var i = 0; i < currProperty.length; i++) {
                currProperty[i]._styling(this._elRef, this, this);
            }
        }
        this.updateStyle();
        this.i.notifySizeChanged();
    };
    IgrToolPanel.prototype.createImplementation = function () {
        return new ToolPanel();
    };
    Object.defineProperty(IgrToolPanel.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "showOnHover", {
        /**
     * Gets or sets if the tool actions should display their submenus on mouse hover.
    */
        get: function () {
            return this.i.al;
        },
        set: function (v) {
            this.i.al = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "cellTextStyle", {
        /**
         * Gets or sets the text style for the panel.
        */
        get: function () {
            if (this.i.ab == null) {
                return null;
            }
            return this.i.ab.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.ab = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "subtitleTextStyle", {
        /**
         * Gets or sets the subtitle text style for the panel.
        */
        get: function () {
            if (this.i.ad == null) {
                return null;
            }
            return this.i.ad.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.ad = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "baseTheme", {
        /**
         * Gets or sets the base built in theme to use for the checkbox.
        */
        get: function () {
            return this.i.u;
        },
        set: function (v) {
            this.i.u = ensureEnum(BaseControlTheme_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "backgroundColor", {
        /**
         * Gets or sets the color to use for the background of the component.
        */
        get: function () {
            return brushToString(this.i.ha);
        },
        set: function (v) {
            this.i.ha = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualBackgroundColor", {
        get: function () {
            return brushToString(this.i.gp);
        },
        set: function (v) {
            this.i.gp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "submenuBackgroundColor", {
        /**
         * Gets or sets the background color for submenus.
        */
        get: function () {
            return brushToString(this.i.ho);
        },
        set: function (v) {
            this.i.ho = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSubmenuBackgroundColor", {
        get: function () {
            return brushToString(this.i.g3);
        },
        set: function (v) {
            this.i.g3 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "groupHeaderBackgroundColor", {
        /**
         * Gets or sets the group header background color.
        */
        get: function () {
            return brushToString(this.i.he);
        },
        set: function (v) {
            this.i.he = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualGroupHeaderBackgroundColor", {
        get: function () {
            return brushToString(this.i.gt);
        },
        set: function (v) {
            this.i.gt = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorBackgroundColor", {
        /**
         * Gets or sets the separator background color.
        */
        get: function () {
            return brushToString(this.i.hn);
        },
        set: function (v) {
            this.i.hn = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorBackgroundColor", {
        get: function () {
            return brushToString(this.i.g2);
        },
        set: function (v) {
            this.i.g2 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "groupHeaderSeparatorBackgroundColor", {
        /**
         * Gets or sets the group header separator background color.
        */
        get: function () {
            return brushToString(this.i.hf);
        },
        set: function (v) {
            this.i.hf = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualGroupHeaderSeparatorBackgroundColor", {
        get: function () {
            return brushToString(this.i.gu);
        },
        set: function (v) {
            this.i.gu = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "hoverBackgroundColor", {
        /**
         * Gets or sets the hover background color.
        */
        get: function () {
            return brushToString(this.i.hj);
        },
        set: function (v) {
            this.i.hj = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualHoverBackgroundColor", {
        get: function () {
            return brushToString(this.i.gy);
        },
        set: function (v) {
            this.i.gy = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "textColor", {
        /**
         * Gets or sets the color to use for the text of the component.
        */
        get: function () {
            return brushToString(this.i.hq);
        },
        set: function (v) {
            this.i.hq = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualTextColor", {
        get: function () {
            return brushToString(this.i.g5);
        },
        set: function (v) {
            this.i.g5 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSubtitleTextColor", {
        get: function () {
            return brushToString(this.i.g4);
        },
        set: function (v) {
            this.i.g4 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "subtitleTextColor", {
        /**
         * Gets or sets the color to use for the subtitle of the component.
        */
        get: function () {
            return brushToString(this.i.hp);
        },
        set: function (v) {
            this.i.hp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "disabledTextColor", {
        /**
         * Gets or sets the color to use for the text in disabled tool actions.
        */
        get: function () {
            return brushToString(this.i.hd);
        },
        set: function (v) {
            this.i.hd = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualDisabledTextColor", {
        get: function () {
            return brushToString(this.i.gs);
        },
        set: function (v) {
            this.i.gs = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "groupHeaderTextColor", {
        /**
         * Gets or sets the text color for group header tool actions.
        */
        get: function () {
            return brushToString(this.i.hh);
        },
        set: function (v) {
            this.i.hh = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualGroupHeaderTextColor", {
        get: function () {
            return brushToString(this.i.gw);
        },
        set: function (v) {
            this.i.gw = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "groupHeaderSubtitleTextColor", {
        /**
         * Gets or sets the text color for group header subtitle.
        */
        get: function () {
            return brushToString(this.i.hg);
        },
        set: function (v) {
            this.i.hg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualGroupHeaderSubtitleTextColor", {
        get: function () {
            return brushToString(this.i.gv);
        },
        set: function (v) {
            this.i.gv = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "toolTipTextColor", {
        /**
         * Gets or sets the tooltip text color.
        */
        get: function () {
            return brushToString(this.i.hs);
        },
        set: function (v) {
            this.i.hs = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualToolTipTextColor", {
        get: function () {
            return brushToString(this.i.g7);
        },
        set: function (v) {
            this.i.g7 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "toolTipBackgroundColor", {
        /**
         * Gets or sets the tooltip background color.
        */
        get: function () {
            return brushToString(this.i.hr);
        },
        set: function (v) {
            this.i.hr = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualToolTipBackgroundColor", {
        /**
         * Gets the actual tooltip background color.
        */
        get: function () {
            return brushToString(this.i.g6);
        },
        set: function (v) {
            this.i.g6 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "toolTipCornerRadius", {
        /**
         * Gets or sets the tooltip corner radius.
        */
        get: function () {
            return this.i.b2;
        },
        set: function (v) {
            this.i.b2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualToolTipCornerRadius", {
        /**
         * Gets the actual tooltip corner radius.
        */
        get: function () {
            return this.i.bq;
        },
        set: function (v) {
            this.i.bq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "toolTipElevation", {
        /**
         * Gets or sets the shadow elevation for the tooltip.
        */
        get: function () {
            return this.i.b3;
        },
        set: function (v) {
            this.i.b3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualToolTipElevation", {
        /**
         * Gets the actual shadow elevation used by the tooltip.
        */
        get: function () {
            return this.i.br;
        },
        set: function (v) {
            this.i.br = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "iconFill", {
        /**
         * Gets or sets the fill color of icons in the ToolPanel.
        */
        get: function () {
            return brushToString(this.i.hk);
        },
        set: function (v) {
            this.i.hk = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualIconFill", {
        /**
         * Gets the actual icon fill color.
        */
        get: function () {
            return brushToString(this.i.gz);
        },
        set: function (v) {
            this.i.gz = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "iconStroke", {
        /**
         * Gets or sets the stroke color of icons in the ToolPanel.
        */
        get: function () {
            return brushToString(this.i.hl);
        },
        set: function (v) {
            this.i.hl = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualIconStroke", {
        /**
         * Gets the actual icon stroke color.
        */
        get: function () {
            return brushToString(this.i.g0);
        },
        set: function (v) {
            this.i.g0 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorVerticalPaddingLeft", {
        /**
         * Gets or sets the left padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.bz;
        },
        set: function (v) {
            this.i.bz = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorVerticalPaddingLeft", {
        get: function () {
            return this.i.bn;
        },
        set: function (v) {
            this.i.bn = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorVerticalPaddingRight", {
        /**
         * Gets or sets the right padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.b0;
        },
        set: function (v) {
            this.i.b0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorVerticalPaddingRight", {
        get: function () {
            return this.i.bo;
        },
        set: function (v) {
            this.i.bo = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorVerticalPaddingTop", {
        /**
         * Gets or sets the top padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.b1;
        },
        set: function (v) {
            this.i.b1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorVerticalPaddingTop", {
        get: function () {
            return this.i.bp;
        },
        set: function (v) {
            this.i.bp = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorVerticalPaddingBottom", {
        /**
         * Gets or sets the bottom padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.by;
        },
        set: function (v) {
            this.i.by = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorVerticalPaddingBottom", {
        get: function () {
            return this.i.bm;
        },
        set: function (v) {
            this.i.bm = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorHorizontalPaddingLeft", {
        /**
         * Gets or sets the left padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.bv;
        },
        set: function (v) {
            this.i.bv = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorHorizontalPaddingLeft", {
        get: function () {
            return this.i.bj;
        },
        set: function (v) {
            this.i.bj = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorHorizontalPaddingRight", {
        /**
         * Gets or sets the right padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.bw;
        },
        set: function (v) {
            this.i.bw = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorHorizontalPaddingRight", {
        get: function () {
            return this.i.bk;
        },
        set: function (v) {
            this.i.bk = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorHorizontalPaddingTop", {
        /**
         * Gets or sets the top padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.bx;
        },
        set: function (v) {
            this.i.bx = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorHorizontalPaddingTop", {
        get: function () {
            return this.i.bl;
        },
        set: function (v) {
            this.i.bl = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "separatorHorizontalPaddingBottom", {
        /**
         * Gets or sets the bottom padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.bu;
        },
        set: function (v) {
            this.i.bu = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualSeparatorHorizontalPaddingBottom", {
        get: function () {
            return this.i.bi;
        },
        set: function (v) {
            this.i.bi = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "orientation", {
        /**
         * Gets or sets the color to use for the background of the component.
        */
        get: function () {
            return this.i.r;
        },
        set: function (v) {
            this.i.r = ensureEnum(ToolPanelOrientation_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "rowHeight", {
        /**
         * Gets or sets the row height for the panel.
        */
        get: function () {
            return this.i.b8;
        },
        set: function (v) {
            this.i.b8 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualRowHeight", {
        /**
         * Gets the actual row height used by the panel.
        */
        get: function () {
            return this.i.bh;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "highlightWidth", {
        get: function () {
            return this.i.bt;
        },
        set: function (v) {
            this.i.bt = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualHighlightWidth", {
        get: function () {
            return this.i.bg;
        },
        set: function (v) {
            this.i.bg = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "highlightRadius", {
        get: function () {
            return this.i.bs;
        },
        set: function (v) {
            this.i.bs = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualHighlightRadius", {
        get: function () {
            return this.i.bf;
        },
        set: function (v) {
            this.i.bf = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "highlightColor", {
        get: function () {
            return brushToString(this.i.hi);
        },
        set: function (v) {
            this.i.hi = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualHighlightColor", {
        get: function () {
            return brushToString(this.i.gx);
        },
        set: function (v) {
            this.i.gx = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "menuArrowStroke", {
        /**
         * Gets or sets the stroke color for all icon menu dropdown arrows.
        */
        get: function () {
            return brushToString(this.i.hm);
        },
        set: function (v) {
            this.i.hm = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualMenuArrowStroke", {
        /**
         * Gets the actual stroke color for all icon menu dropdown arrows.
        */
        get: function () {
            return brushToString(this.i.g1);
        },
        set: function (v) {
            this.i.g1 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.ht);
        },
        set: function (v) {
            this.i.ht = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.g8);
        },
        set: function (v) {
            this.i.g8 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hb);
        },
        set: function (v) {
            this.i.hb = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gq);
        },
        set: function (v) {
            this.i.gq = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hu);
        },
        set: function (v) {
            this.i.hu = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.g9);
        },
        set: function (v) {
            this.i.g9 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hc);
        },
        set: function (v) {
            this.i.hc = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.gr);
        },
        set: function (v) {
            this.i.gr = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "dropdownDelay", {
        /**
         * Gets or sets the dropdown delay time in milliseconds.
        */
        get: function () {
            return this.i.b7;
        },
        set: function (v) {
            this.i.b7 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "actualDropdownDelay", {
        /**
         * Gets the actual dropdown delay.
        */
        get: function () {
            return this.i.b6;
        },
        set: function (v) {
            this.i.b6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "nestedActionMode", {
        /**
         * Gets or sets the mode used when displaying nested actions.
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = ensureEnum(NestedActionMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrToolPanel.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.actions != null && this.actions.findByName && this.actions.findByName(name)) {
            return this.actions.findByName(name);
        }
        return null;
    };
    Object.defineProperty(IgrToolPanel.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolPanel.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrToolPanel.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("ToolPanel");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    IgrToolPanel.prototype.refresh = function () {
        this.i.fb();
    };
    IgrToolPanel.prototype.getDesiredSize = function () {
        var iv = this.i.hv();
        return fromSize(iv);
    };
    /**
     * Forces any open sub menus to close.
    
    */
    IgrToolPanel.prototype.closeSubmenus = function () {
        this.i.er();
    };
    IgrToolPanel.prototype.exportVisualData = function () {
        var iv = this.i.b9();
        return (iv);
    };
    IgrToolPanel.prototype.exportSerializedVisualData = function () {
        var iv = this.i.dl();
        return (iv);
    };
    Object.defineProperty(IgrToolPanel.prototype, "contentRefreshed", {
        get: function () {
            return this._contentRefreshed;
        },
        set: function (ev) {
            var _this = this;
            if (this._contentRefreshed_wrapped !== null) {
                this.i.contentRefreshed = delegateRemove(this.i.contentRefreshed, this._contentRefreshed_wrapped);
                this._contentRefreshed_wrapped = null;
                this._contentRefreshed = null;
            }
            this._contentRefreshed = ev;
            this._contentRefreshed_wrapped = function (o, e) {
                var outerArgs = new IgrToolPanelContentRefreshedEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeContentRefreshed) {
                    _this.beforeContentRefreshed(_this, outerArgs);
                }
                if (_this._contentRefreshed) {
                    _this._contentRefreshed(_this, outerArgs);
                }
            };
            this.i.contentRefreshed = delegateCombine(this.i.contentRefreshed, this._contentRefreshed_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolPanel.prototype, "onCommand", {
        get: function () {
            return this._onCommand;
        },
        set: function (ev) {
            var _this = this;
            if (this._onCommand_wrapped !== null) {
                this.i.onCommand = delegateRemove(this.i.onCommand, this._onCommand_wrapped);
                this._onCommand_wrapped = null;
                this._onCommand = null;
            }
            this._onCommand = ev;
            this._onCommand_wrapped = function (o, e) {
                var outerArgs = new IgrToolCommandEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeOnCommand) {
                    _this.beforeOnCommand(_this, outerArgs);
                }
                if (_this._onCommand) {
                    _this._onCommand(_this, outerArgs);
                }
            };
            this.i.onCommand = delegateCombine(this.i.onCommand, this._onCommand_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolPanel;
}(React.Component));
export { IgrToolPanel };
