import { __extends, __values } from "tslib";
import * as React from 'react';
import { fromSize, ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, isValidProp, toSpinal, getModifiedProps } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
import { CollectionAdapter } from "igniteui-react-core";
import { NotifyCollectionChangedAction } from "igniteui-react-core";
import { Toolbar } from './Toolbar';
import { BaseControlTheme_$type } from "igniteui-react-core";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
import { ToolbarOrientation_$type } from './ToolbarOrientation';
import { ToolActionCollection as ToolActionCollection_internal } from "./ToolActionCollection";
import { ToolAction } from "./ToolAction";
import { IgrToolActionCollection } from "./igr-tool-action-collection";
import { IgrToolCommandEventArgs } from './igr-tool-command-event-args';
var IgrToolbar = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolbar, _super);
    function IgrToolbar(props) {
        var _this = _super.call(this, props) || this;
        _this._implementation = null;
        _this._reactRenderer = null;
        _this.contentActions = [];
        /**
        * The style mappings actually present in the treemap. Do not directly modify this array.
        * This array's contents can be modified by causing React to reproject the child content.
        * Or adding and removing ranges from the manual ranges collection on the ranges property.
        */
        _this.combinedActions = [];
        _this._actions = null;
        _this._actionsAdapter = null;
        _this._autoGeneratedActions = null;
        _this._actualActions = null;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        _this._onCommand = null;
        _this._onCommand_wrapped = null;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._implementation = _this.createImplementation();
        _this._getMainRef = _this._getMainRef.bind(_this);
        _this._contentChildrenManager = new ContentChildrenManager(function (ch) { return ch.key || ch.props.name; }, function (ch) { return ch.key || ch.props.name; }, function () { return _this._updateContentChildren(); });
        _this._actionsAdapter = new CollectionAdapter(_this.contentActions, _this.i.actions, _this.combinedActions, function (c) { return c.i; }, function (i) {
            if (_this._reactRenderer && _this._elRef) {
                i._styling(_this._elRef, _this, _this);
            }
        }, function (i) { });
        //var multiColumnComboBox = this.i;
        //multiColumnComboBox.notifySizeChanged();
        if (props) {
            _this.initializeProperties();
        }
        _this._initialized = true;
        return _this;
    }
    Object.defineProperty(IgrToolbar.prototype, "height", {
        get: function () {
            return this._height;
        },
        set: function (value) {
            this._height = value;
            this.i.userSetHeight = value ? true : false;
            if (this._elRef) {
                this._elRef.style.height = value;
                this.i.notifySizeChanged();
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "width", {
        get: function () {
            return this._width;
        },
        set: function (value) {
            this._width = value;
            this.i.userSetWidth = value ? true : false;
            if (this._elRef) {
                this._elRef.style.height = value;
                this.i.notifySizeChanged();
            }
        },
        enumerable: false,
        configurable: true
    });
    IgrToolbar.prototype._getMainRef = function (ref) {
        this._elRef = ref;
        this.verifyReferences();
    };
    IgrToolbar.prototype._updateContentChildren = function () {
        this.contentActions.length = 0;
        var contentChildrenActual = this._contentChildrenManager.contentChildrenActual;
        for (var i = 0; i < contentChildrenActual.length; i++) {
            if ((ToolAction.$type).isAssignableFrom(contentChildrenActual[i].i.$type)) {
                this.contentActions.push(contentChildrenActual[i]);
            }
        }
        if (this._actionsAdapter !== null) {
            this._actionsAdapter.notifyContentChanged();
        }
    };
    Object.defineProperty(IgrToolbar.prototype, "actions", {
        /**
         * A collection of manually added style mappings for the treemap.
        */
        get: function () {
            var _this = this;
            if (this._actions === null) {
                var coll = new IgrToolActionCollection();
                var inner = coll._innerColl;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._actionsAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._actionsAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._actionsAdapter.clearManualItems();
                            break;
                    }
                });
                this._actions = coll;
            }
            return this._actions;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolbar.prototype.render = function () {
        var children = this._contentChildrenManager.getChildren(this.props.children);
        if (this._portalManager)
            this._portalManager.onRender(children);
        var div = React.createElement("div", {
            ref: this._getMainRef,
            className: "ig-toolbar igr-toolbar",
            children: children
        });
        return div;
    };
    IgrToolbar.prototype.verifyReferences = function () {
        var _this = this;
        if (this._elRef) {
            this.requestRender = this.requestRender.bind(this);
            this._portalManager = new PortalManager("toolbarContent", this.requestRender);
            this._reactRenderer = new ReactRenderer(this._elRef, document, true, {}, this._portalManager);
            if (document) {
                this._elRef.style.display = "block";
                this._elRef.style.width = "100%";
                this._elRef.style.height = "100%";
            }
            // render needs to fire again after the portalManager is created. 
            this.requestRender();
            this.i.provideContainer(this._reactRenderer);
            this.i.notifySizeChanged();
            this._reactRenderer.addSizeWatcher(function () {
                _this.i.notifySizeChanged();
            });
        }
    };
    IgrToolbar.prototype.requestRender = function () {
        if (this._initialized)
            this.setState({});
    };
    IgrToolbar.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_1, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
        return true;
    };
    IgrToolbar.prototype.initializeProperties = function () {
        var e_2, _a;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
    };
    // supports angular themes or custom properties set in CSS
    IgrToolbar.prototype.updateStyle = function () {
        this._styling(this._elRef, this);
    };
    IgrToolbar.prototype.componentWillUnmount = function () {
        this.i.destroy();
        if (this._reactRenderer)
            this._reactRenderer.destroy();
    };
    IgrToolbar.prototype.componentDidMount = function () {
        this._elRef.style.width = this._width ? this._width : "";
        this._elRef.style.height = this._height ? this._height : "";
        this.i.notifySizeChanged();
        this.initializeContent();
    };
    IgrToolbar.prototype.initializeContent = function () {
        this._styling(this._elRef, this);
        if (this.combinedActions && this.combinedActions.length > 0) {
            var currProperty = this.combinedActions;
            for (var i = 0; i < currProperty.length; i++) {
                currProperty[i]._styling(this._elRef, this, this);
            }
        }
        this.updateStyle();
        this.i.notifySizeChanged();
    };
    IgrToolbar.prototype.createImplementation = function () {
        return new Toolbar();
    };
    Object.defineProperty(IgrToolbar.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "target", {
        /**
         * Gets or sets a target component which the toolbar can request actions from.
         */
        get: function () {
            var ret = this.i.target;
            if (!ret) {
                return ret;
            }
            if (ret.externalObject != null) {
                ret = ret.externalObject;
            }
            return ret;
        },
        set: function (v) {
            if (v && v._implementation) {
                v = v._implementation;
            }
            this.i.target = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "baseTheme", {
        /**
     * Gets or sets the base built in theme to use for the checkbox.
    */
        get: function () {
            return this.i.r;
        },
        set: function (v) {
            this.i.r = ensureEnum(BaseControlTheme_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "autoGeneratedActions", {
        /**
         * Gets or sets the data or data source instance to which to bind the grid.
        */
        get: function () {
            if (this._autoGeneratedActions === null) {
                var coll = new IgrToolActionCollection();
                var innerColl = this.i.autoGeneratedActions;
                if (!innerColl) {
                    innerColl = new ToolActionCollection_internal();
                }
                this._autoGeneratedActions = coll._fromInner(innerColl);
                this.i.autoGeneratedActions = innerColl;
            }
            return this._autoGeneratedActions;
        },
        set: function (v) {
            if (this._autoGeneratedActions !== null) {
                this._autoGeneratedActions._setSyncTarget(null);
                this._autoGeneratedActions = null;
            }
            var coll = new IgrToolActionCollection();
            this._autoGeneratedActions = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(ToolAction.$type);
            var innerColl = this.i.autoGeneratedActions;
            if (!innerColl) {
                innerColl = new ToolActionCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._autoGeneratedActions._setSyncTarget(syncColl);
            this.i.autoGeneratedActions = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "actualActions", {
        /**
         * Gets or sets the data or data source instance to which to bind the grid.
        */
        get: function () {
            if (this._actualActions === null) {
                var coll = new IgrToolActionCollection();
                var innerColl = this.i.actualActions;
                if (!innerColl) {
                    innerColl = new ToolActionCollection_internal();
                }
                this._actualActions = coll._fromInner(innerColl);
                this.i.actualActions = innerColl;
            }
            return this._actualActions;
        },
        set: function (v) {
            if (this._actualActions !== null) {
                this._actualActions._setSyncTarget(null);
                this._actualActions = null;
            }
            var coll = new IgrToolActionCollection();
            this._actualActions = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(ToolAction.$type);
            var innerColl = this.i.actualActions;
            if (!innerColl) {
                innerColl = new ToolActionCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._actualActions._setSyncTarget(syncColl);
            this.i.actualActions = innerColl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "orientation", {
        /**
         * Gets or sets the orientation of the toolbar.
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = ensureEnum(ToolbarOrientation_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "backgroundColor", {
        /**
         * Gets or sets the color to use for the background of the component.
        */
        get: function () {
            return brushToString(this.i.d4);
        },
        set: function (v) {
            this.i.d4 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "submenuBackgroundColor", {
        /**
         * Gets or sets the background color for submenus.
        */
        get: function () {
            return brushToString(this.i.eh);
        },
        set: function (v) {
            this.i.eh = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "groupHeaderBackgroundColor", {
        /**
         * Gets or sets the group header background color.
        */
        get: function () {
            return brushToString(this.i.d8);
        },
        set: function (v) {
            this.i.d8 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorBackgroundColor", {
        /**
         * Gets or sets the separator background color.
        */
        get: function () {
            return brushToString(this.i.eg);
        },
        set: function (v) {
            this.i.eg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "hoverBackgroundColor", {
        /**
         * Gets or sets the hover background color.
        */
        get: function () {
            return brushToString(this.i.ec);
        },
        set: function (v) {
            this.i.ec = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "textColor", {
        /**
         * Gets or sets the color to use for the text of the component.
        */
        get: function () {
            return brushToString(this.i.ej);
        },
        set: function (v) {
            this.i.ej = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "disabledTextColor", {
        /**
         * Gets or sets the color to use for the text in disabled tool actions.
        */
        get: function () {
            return brushToString(this.i.d7);
        },
        set: function (v) {
            this.i.d7 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "groupHeaderTextColor", {
        /**
         * Gets or sets the text color for group header tool actions.
        */
        get: function () {
            return brushToString(this.i.ea);
        },
        set: function (v) {
            this.i.ea = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "toolTipTextColor", {
        /**
         * Gets or sets the tooltip text color.
        */
        get: function () {
            return brushToString(this.i.el);
        },
        set: function (v) {
            this.i.el = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "toolTipBackgroundColor", {
        /**
         * Gets or sets the tooltip background color.
        */
        get: function () {
            return brushToString(this.i.ek);
        },
        set: function (v) {
            this.i.ek = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "toolTipCornerRadius", {
        /**
         * Gets or sets the tooltip corner radius.
        */
        get: function () {
            return this.i.a5;
        },
        set: function (v) {
            this.i.a5 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "toolTipElevation", {
        /**
         * Gets or sets the shadow elevation for the tooltip.
        */
        get: function () {
            return this.i.a6;
        },
        set: function (v) {
            this.i.a6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "iconFill", {
        /**
         * Gets or sets the fill color of icons in the ToolPanel.
        */
        get: function () {
            return brushToString(this.i.ed);
        },
        set: function (v) {
            this.i.ed = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "iconStroke", {
        /**
         * Gets or sets the stroke color of icons in the ToolPanel.
        */
        get: function () {
            return brushToString(this.i.ee);
        },
        set: function (v) {
            this.i.ee = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "cellTextStyle", {
        /**
         * Gets or sets the text style.
        */
        get: function () {
            if (this.i.v == null) {
                return null;
            }
            return this.i.v.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.v = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "subtitleTextStyle", {
        /**
         * Gets or sets the text style for subtitles.
        */
        get: function () {
            if (this.i.x == null) {
                return null;
            }
            return this.i.x.fontString;
        },
        set: function (v) {
            var fi = new FontInfo();
            fi.fontString = v;
            this.i.x = fi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorVerticalPaddingLeft", {
        /**
         * Gets or sets the left padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.a2;
        },
        set: function (v) {
            this.i.a2 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorVerticalPaddingRight", {
        /**
         * Gets or sets the right padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.a3;
        },
        set: function (v) {
            this.i.a3 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorVerticalPaddingTop", {
        /**
         * Gets or sets the top padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.a4;
        },
        set: function (v) {
            this.i.a4 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorVerticalPaddingBottom", {
        /**
         * Gets or sets the bottom padding for separators in the vertical orientation.
        */
        get: function () {
            return this.i.a1;
        },
        set: function (v) {
            this.i.a1 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorHorizontalPaddingLeft", {
        /**
         * Gets or sets the left padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.ay;
        },
        set: function (v) {
            this.i.ay = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorHorizontalPaddingRight", {
        /**
         * Gets or sets the right padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.az;
        },
        set: function (v) {
            this.i.az = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorHorizontalPaddingTop", {
        /**
         * Gets or sets the top padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.a0;
        },
        set: function (v) {
            this.i.a0 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "separatorHorizontalPaddingBottom", {
        /**
         * Gets or sets the bottom padding for separators in the horizontal orientation.
        */
        get: function () {
            return this.i.ax;
        },
        set: function (v) {
            this.i.ax = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "showOnHover", {
        /**
         * Gets or sets if the tool actions should display their submenus on mouse hover.
        */
        get: function () {
            return this.i.ag;
        },
        set: function (v) {
            this.i.ag = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "highlightWidth", {
        get: function () {
            return this.i.aw;
        },
        set: function (v) {
            this.i.aw = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "highlightRadius", {
        get: function () {
            return this.i.av;
        },
        set: function (v) {
            this.i.av = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "highlightColor", {
        get: function () {
            return brushToString(this.i.eb);
        },
        set: function (v) {
            this.i.eb = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "menuArrowStroke", {
        /**
         * Gets or sets the stroke color for all icon menu dropdown arrows.
        */
        get: function () {
            return brushToString(this.i.ef);
        },
        set: function (v) {
            this.i.ef = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.em);
        },
        set: function (v) {
            this.i.em = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.d5);
        },
        set: function (v) {
            this.i.d5 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.en);
        },
        set: function (v) {
            this.i.en = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the radio when in the checked state.
        */
        get: function () {
            return brushToString(this.i.d6);
        },
        set: function (v) {
            this.i.d6 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "rowHeight", {
        /**
         * Gets or sets the row height that should be used.
        */
        get: function () {
            return this.i.ba;
        },
        set: function (v) {
            this.i.ba = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "subtitleTextColor", {
        /**
         * Gets or sets the text color for subtitles.
        */
        get: function () {
            return brushToString(this.i.ei);
        },
        set: function (v) {
            this.i.ei = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "groupHeaderSubtitleTextColor", {
        /**
         * Gets or sets the text color for group header subtitles.
        */
        get: function () {
            return brushToString(this.i.d9);
        },
        set: function (v) {
            this.i.d9 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolbar.prototype, "dropdownDelay", {
        /**
         * Gets or sets the dropdown delay time in milliseconds.
        */
        get: function () {
            return this.i.a9;
        },
        set: function (v) {
            this.i.a9 = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolbar.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.autoGeneratedActions != null && this.autoGeneratedActions.findByName && this.autoGeneratedActions.findByName(name)) {
            return this.autoGeneratedActions.findByName(name);
        }
        if (this.actions != null && this.actions.findByName && this.actions.findByName(name)) {
            return this.actions.findByName(name);
        }
        if (this.actualActions != null && this.actualActions.findByName && this.actualActions.findByName(name)) {
            return this.actualActions.findByName(name);
        }
        return null;
    };
    Object.defineProperty(IgrToolbar.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrToolbar.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrToolbar.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Toolbar");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    /**
 * Get the desired size the toolbar wants to be.

*/
    IgrToolbar.prototype.getDesiredSize = function () {
        var iv = this.i.eo();
        return fromSize(iv);
    };
    /**
     * Forces any open sub menus to close.
    
    */
    IgrToolbar.prototype.closeSubmenus = function () {
        this.i.cw();
    };
    IgrToolbar.prototype.onCommandStateChanged = function (id, type, value) {
        this.i.onCommandStateChanged(id, (type == null ? null : type), value);
    };
    IgrToolbar.prototype.registerIconFromText = function (iconCollection, iconName, iconText) {
        this.i.dd(iconCollection, iconName, iconText);
    };
    IgrToolbar.prototype.getIconFromCache = function (iconCollection, iconName) {
        var iv = this.i.bt(iconCollection, iconName);
        return (iv);
    };
    IgrToolbar.prototype.registerMultiPathSVG = function (iconCollection, iconName, multiPathSVG) {
        this.i.de(iconCollection, iconName, multiPathSVG);
    };
    IgrToolbar.prototype.getMultiPathSVGFromCache = function (iconCollection, iconName) {
        var iv = this.i.a(iconCollection, iconName);
        return (iv);
    };
    IgrToolbar.prototype.setContextItem = function (key, value) {
        this.i.df(key, value);
    };
    IgrToolbar.prototype.getContextItem = function (key) {
        var iv = this.i.be(key);
        return (iv);
    };
    /**
     * Exports visual information about the current state of the grid.
    
    */
    IgrToolbar.prototype.exportVisualData = function () {
        var iv = this.i.bd();
        return (iv);
    };
    /**
     * Returns a serialized copy of the exported visual model
    
    */
    IgrToolbar.prototype.exportSerializedVisualData = function () {
        var iv = this.i.bs();
        return (iv);
    };
    Object.defineProperty(IgrToolbar.prototype, "onCommand", {
        /**
         * Event raised when a command is triggered in the toolbar.
        */
        get: function () {
            return this._onCommand;
        },
        set: function (ev) {
            var _this = this;
            if (this._onCommand_wrapped !== null) {
                this.i.onCommand = delegateRemove(this.i.onCommand, this._onCommand_wrapped);
                this._onCommand_wrapped = null;
                this._onCommand = null;
            }
            this._onCommand = ev;
            this._onCommand_wrapped = function (o, e) {
                var outerArgs = new IgrToolCommandEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeOnCommand) {
                    _this.beforeOnCommand(_this, outerArgs);
                }
                if (_this._onCommand) {
                    _this._onCommand(_this, outerArgs);
                }
            };
            this.i.onCommand = delegateCombine(this.i.onCommand, this._onCommand_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolbar;
}(React.Component));
export { IgrToolbar };
