import * as React from 'react';
import { IgrToolActionCollection } from "./igr-tool-action-collection";
import { Visibility } from "igniteui-react-core";
import { IgrToolCommandEventArgs } from "./igr-tool-command-event-args";
import { IgrToolActionPerformedEventArgs } from "./igr-tool-action-performed-event-args";
import { ToolAction } from "./ToolAction";
import { ContentChildrenManager } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
/**
 * Represents base class for all tool actions in toolbar
*/
export declare abstract class IgrToolAction<P extends IIgrToolActionProps = IIgrToolActionProps> extends React.Component<P, {}> {
    protected createImplementation(): ToolAction;
    protected _implementation: any;
    protected mounted: boolean;
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     */
    get i(): ToolAction; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrToolAction;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    get id(): string;
    private _actions;
    /**
     * Gets the sub actions associated with this tool action.
    */
    get actions(): IgrToolActionCollection;
    set actions(v: IgrToolActionCollection);
    /**
     * Gets or sets the width to use for this tool action.
    */
    get width(): number;
    set width(v: number);
    get parentId(): string;
    set parentId(v: string);
    /**
     * Gets or sets the Id of the action that this action will be inserted before.
     * Subsequent actions will continue to insert before the target action, following
     * the original action that set this property. If using this property do not use the
     * AfterId property.
     * This property is only relevant during initial insertion into the toolbar. Changing the property
     * after the action has already been added will have no effect.
    */
    get beforeId(): string;
    set beforeId(v: string);
    /**
     * Gets or sets the Id of the action that this action will be inserted after.
     * Subsequent actions will continue to insert after the target action, following
     * the original action that set this property. If using this property do not use the
     * BeforeId property.
     * This property is only relevant during initial insertion into the toolbar. Changing the property
     * after the action has already been added will have no effect.
    */
    get afterId(): string;
    set afterId(v: string);
    /**
     * Sets to the Id of the action that this action will overlay itself on to.
     * The purpose of this property is to allow users to override actions automatically generated by
     * toolbar targets such as the DataChart. These generated actions all have unique Ids associated
     * with them that can be used for the OverlayId.
     * These overlaid actions will
     * not
     * replace the generated one but will have its properties
     * overlaid onto the generated actions.
    */
    get overlayId(): string;
    set overlayId(v: string);
    get commandId(): string;
    set commandId(v: string);
    get commandArgument(): string;
    set commandArgument(v: string);
    get commandArgumentValue(): any;
    set commandArgumentValue(v: any);
    get paddingLeft(): number;
    set paddingLeft(v: number);
    get actualPaddingLeft(): number;
    set actualPaddingLeft(v: number);
    get paddingRight(): number;
    set paddingRight(v: number);
    get actualPaddingRight(): number;
    set actualPaddingRight(v: number);
    get paddingBottom(): number;
    set paddingBottom(v: number);
    get actualPaddingBottom(): number;
    set actualPaddingBottom(v: number);
    get paddingTop(): number;
    set paddingTop(v: number);
    get actualPaddingTop(): number;
    set actualPaddingTop(v: number);
    /**
     * Gets the actual hover background used by the tool action.
    */
    get actualHoverBackground(): string;
    set actualHoverBackground(v: string);
    /**
     * Gets or sets the hover background for this tool action.
    */
    get hoverBackground(): string;
    set hoverBackground(v: string);
    /**
     * Gets the actual background used by the tool action.
    */
    get actualBackground(): string;
    set actualBackground(v: string);
    /**
     * Gets or sets the background color of the tool action.
    */
    get background(): string;
    set background(v: string);
    /**
     * Gets the actual label text color.
    */
    get actualTextColor(): string;
    set actualTextColor(v: string);
    /**
     * Gets or sets the label text color.
    */
    get textColor(): string;
    set textColor(v: string);
    /**
     * Gets the actual label text color.
    */
    get actualSubtitleTextColor(): string;
    set actualSubtitleTextColor(v: string);
    /**
     * Gets or sets the label text color.
    */
    get subtitleTextColor(): string;
    set subtitleTextColor(v: string);
    /**
     * Gets the actual label text color when the tool is disabled.
    */
    get actualDisabledTextColor(): string;
    set actualDisabledTextColor(v: string);
    /**
     * Gets or sets the label text color when the tool is disabled.
    */
    get disabledTextColor(): string;
    set disabledTextColor(v: string);
    /**
     * Gets the actual font used.
    */
    get actualTextStyle(): FontInfo;
    set actualTextStyle(v: FontInfo);
    /**
     * Gets or sets the font to use.
    */
    get textStyle(): string;
    set textStyle(v: string);
    /**
     * Gets the actual font used.
    */
    get actualSubtitleTextStyle(): FontInfo;
    set actualSubtitleTextStyle(v: FontInfo);
    /**
     * Gets or sets the font to use.
    */
    get subtitleTextStyle(): string;
    set subtitleTextStyle(v: string);
    get isDisabled(): boolean;
    set isDisabled(v: boolean);
    get isHighlighted(): boolean;
    set isHighlighted(v: boolean);
    get name(): string;
    set name(v: string);
    /**
     * Gets or sets the title of the tool.
    */
    get title(): string;
    set title(v: string);
    /**
     * Gets or sets the subtitle of the tool.
    */
    get subtitle(): string;
    set subtitle(v: string);
    get iconName(): string;
    set iconName(v: string);
    get iconCollectionName(): string;
    set iconCollectionName(v: string);
    /**
     * Gets or sets the icon viewbox left.
    */
    get iconViewBoxLeft(): number;
    set iconViewBoxLeft(v: number);
    /**
     * Gets or sets the icon viewbox top.
    */
    get iconViewBoxTop(): number;
    set iconViewBoxTop(v: number);
    /**
     * Gets or sets the icon viewbox width.
    */
    get iconViewBoxWidth(): number;
    set iconViewBoxWidth(v: number);
    /**
     * Gets or sets the icon viewbox height.
    */
    get iconViewBoxHeight(): number;
    set iconViewBoxHeight(v: number);
    /**
     * Gets or sets the icon fill color.
    */
    get iconFill(): string;
    set iconFill(v: string);
    /**
     * Gets the actual icon fill color.
    */
    get actualIconFill(): string;
    set actualIconFill(v: string);
    /**
     * Gets or sets the icon fill colors.
    */
    get iconFillColors(): string[];
    set iconFillColors(v: string[]);
    /**
     * Gets or sets the icon stroke color.
    */
    get iconStroke(): string;
    set iconStroke(v: string);
    /**
     * Gets the actual icon stroke color.
    */
    get actualIconStroke(): string;
    set actualIconStroke(v: string);
    /**
     * Gets or sets the icon stroke colors.
    */
    get iconStrokeColors(): string[];
    set iconStrokeColors(v: string[]);
    /**
     * Gets or sets the icon viewbox width.
    */
    get iconStrokeWidth(): number;
    set iconStrokeWidth(v: number);
    /**
     * Gets or sets the width of the icon.
    */
    get iconWidth(): number;
    set iconWidth(v: number);
    /**
     * Gets the actual icon width used.
    */
    get actualIconWidth(): number;
    set actualIconWidth(v: number);
    /**
     * Gets or sets the height of the icon.
    */
    get iconHeight(): number;
    set iconHeight(v: number);
    /**
     * Gets the actual icon height used.
    */
    get actualIconHeight(): number;
    set actualIconHeight(v: number);
    /**
     * Gets or sets the tool action visibility.
    */
    get visibility(): Visibility;
    set visibility(v: Visibility);
    /**
     * Gets or sets if the tool action will close its parent dropdown when executed by the user.
    */
    get closeOnExecute(): boolean;
    set closeOnExecute(v: boolean);
    get highlightWidth(): number;
    set highlightWidth(v: number);
    get actualHighlightWidth(): number;
    set actualHighlightWidth(v: number);
    get highlightRadius(): number;
    set highlightRadius(v: number);
    get actualHighlightRadius(): number;
    set actualHighlightRadius(v: number);
    get highlightColor(): string;
    set highlightColor(v: string);
    get actualHighlightColor(): string;
    set actualHighlightColor(v: string);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    cleanUp(): void;
    openSubMenu(): void;
    closeSubmenu(): void;
    exportVisualData(): any;
    exportSerializedVisualData(): string;
    private _onCommand;
    private _onCommand_wrapped;
    get onCommand(): (s: IgrToolAction, e: IgrToolCommandEventArgs) => void;
    set onCommand(ev: (s: IgrToolAction, e: IgrToolCommandEventArgs) => void);
    private _performed;
    private _performed_wrapped;
    get performed(): (s: IgrToolAction, e: IgrToolActionPerformedEventArgs) => void;
    set performed(ev: (s: IgrToolAction, e: IgrToolActionPerformedEventArgs) => void);
}
export interface IIgrToolActionProps {
    children?: React.ReactNode;
    /**
     * Gets or sets the width to use for this tool action.
    */
    width?: number | string;
    parentId?: string;
    /**
     * Gets or sets the Id of the action that this action will be inserted before.
     * Subsequent actions will continue to insert before the target action, following
     * the original action that set this property. If using this property do not use the
     * AfterId property.
     * This property is only relevant during initial insertion into the toolbar. Changing the property
     * after the action has already been added will have no effect.
    */
    beforeId?: string;
    /**
     * Gets or sets the Id of the action that this action will be inserted after.
     * Subsequent actions will continue to insert after the target action, following
     * the original action that set this property. If using this property do not use the
     * BeforeId property.
     * This property is only relevant during initial insertion into the toolbar. Changing the property
     * after the action has already been added will have no effect.
    */
    afterId?: string;
    /**
     * Sets to the Id of the action that this action will overlay itself on to.
     * The purpose of this property is to allow users to override actions automatically generated by
     * toolbar targets such as the DataChart. These generated actions all have unique Ids associated
     * with them that can be used for the OverlayId.
     * These overlaid actions will
     * not
     * replace the generated one but will have its properties
     * overlaid onto the generated actions.
    */
    overlayId?: string;
    commandId?: string;
    commandArgument?: string;
    commandArgumentValue?: any;
    paddingLeft?: number | string;
    actualPaddingLeft?: number | string;
    paddingRight?: number | string;
    actualPaddingRight?: number | string;
    paddingBottom?: number | string;
    actualPaddingBottom?: number | string;
    paddingTop?: number | string;
    actualPaddingTop?: number | string;
    /**
     * Gets the actual hover background used by the tool action.
    */
    actualHoverBackground?: string;
    /**
     * Gets or sets the hover background for this tool action.
    */
    hoverBackground?: string;
    /**
     * Gets the actual background used by the tool action.
    */
    actualBackground?: string;
    /**
     * Gets or sets the background color of the tool action.
    */
    background?: string;
    /**
     * Gets the actual label text color.
    */
    actualTextColor?: string;
    /**
     * Gets or sets the label text color.
    */
    textColor?: string;
    /**
     * Gets the actual label text color.
    */
    actualSubtitleTextColor?: string;
    /**
     * Gets or sets the label text color.
    */
    subtitleTextColor?: string;
    /**
     * Gets the actual label text color when the tool is disabled.
    */
    actualDisabledTextColor?: string;
    /**
     * Gets or sets the label text color when the tool is disabled.
    */
    disabledTextColor?: string;
    /**
     * Gets the actual font used.
    */
    actualTextStyle?: FontInfo;
    /**
     * Gets or sets the font to use.
    */
    textStyle?: string;
    /**
     * Gets the actual font used.
    */
    actualSubtitleTextStyle?: FontInfo;
    /**
     * Gets or sets the font to use.
    */
    subtitleTextStyle?: string;
    isDisabled?: boolean | string;
    isHighlighted?: boolean | string;
    name?: string;
    /**
     * Gets or sets the title of the tool.
    */
    title?: string;
    /**
     * Gets or sets the subtitle of the tool.
    */
    subtitle?: string;
    iconName?: string;
    iconCollectionName?: string;
    /**
     * Gets or sets the icon viewbox left.
    */
    iconViewBoxLeft?: number | string;
    /**
     * Gets or sets the icon viewbox top.
    */
    iconViewBoxTop?: number | string;
    /**
     * Gets or sets the icon viewbox width.
    */
    iconViewBoxWidth?: number | string;
    /**
     * Gets or sets the icon viewbox height.
    */
    iconViewBoxHeight?: number | string;
    /**
     * Gets or sets the icon fill color.
    */
    iconFill?: string;
    /**
     * Gets the actual icon fill color.
    */
    actualIconFill?: string;
    /**
     * Gets or sets the icon fill colors.
    */
    iconFillColors?: string[] | string;
    /**
     * Gets or sets the icon stroke color.
    */
    iconStroke?: string;
    /**
     * Gets the actual icon stroke color.
    */
    actualIconStroke?: string;
    /**
     * Gets or sets the icon stroke colors.
    */
    iconStrokeColors?: string[] | string;
    /**
     * Gets or sets the icon viewbox width.
    */
    iconStrokeWidth?: number | string;
    /**
     * Gets or sets the width of the icon.
    */
    iconWidth?: number | string;
    /**
     * Gets the actual icon width used.
    */
    actualIconWidth?: number | string;
    /**
     * Gets or sets the height of the icon.
    */
    iconHeight?: number | string;
    /**
     * Gets the actual icon height used.
    */
    actualIconHeight?: number | string;
    /**
     * Gets or sets the tool action visibility.
    */
    visibility?: Visibility | string;
    /**
     * Gets or sets if the tool action will close its parent dropdown when executed by the user.
    */
    closeOnExecute?: boolean | string;
    highlightWidth?: number | string;
    actualHighlightWidth?: number | string;
    highlightRadius?: number | string;
    actualHighlightRadius?: number | string;
    highlightColor?: string;
    actualHighlightColor?: string;
    onCommand?: (s: IgrToolAction, e: IgrToolCommandEventArgs) => void;
    performed?: (s: IgrToolAction, e: IgrToolActionPerformedEventArgs) => void;
}
