import * as React from 'react';
import { IgSize } from "igniteui-react-core";
import { ToolPanel } from './ToolPanel';
import { BaseControlTheme } from "igniteui-react-core";
import { ToolPanelOrientation } from './ToolPanelOrientation';
import { IgrToolActionCollection } from "./igr-tool-action-collection";
import { IgrToolPanelContentRefreshedEventArgs } from "./igr-tool-panel-content-refreshed-event-args";
import { IgrToolAction } from './igr-tool-action';
import { IgrToolCommandEventArgs } from './igr-tool-command-event-args';
import { NestedActionMode } from './NestedActionMode';
export declare class IgrToolPanel extends React.Component<IIgrToolPanelProps> {
    private _implementation;
    private _reactRenderer;
    private _height;
    private _width;
    private _initialized;
    private _elRef;
    private _portalManager;
    set height(value: string);
    get height(): string;
    set width(value: string);
    get width(): string;
    private _getMainRef;
    private _contentChildrenManager;
    private _updateContentChildren;
    contentActions: IgrToolAction[];
    /**
    * The style mappings actually present in the treemap. Do not directly modify this array.
    * This array's contents can be modified by causing React to reproject the child content.
    * Or adding and removing ranges from the manual ranges collection on the ranges property.
    */
    actualActions: IgrToolAction[];
    private _actions;
    private _actionsAdapter;
    /**
     * A collection of manually added style mappings for the treemap.
    */
    get actions(): IgrToolActionCollection;
    render(): React.DetailedReactHTMLElement<{
        ref: (ref: any) => void;
        className: string;
        children: any[];
    }, any>;
    private verifyReferences;
    private requestRender;
    constructor(props: IIgrToolPanelProps);
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    protected initializeProperties(): void;
    updateStyle(): void;
    componentWillUnmount(): void;
    componentDidMount(): void;
    initializeContent(): void;
    protected createImplementation(): ToolPanel;
    get i(): ToolPanel;
    /**
 * Gets or sets if the tool actions should display their submenus on mouse hover.
*/
    get showOnHover(): boolean;
    set showOnHover(v: boolean);
    /**
     * Gets or sets the text style for the panel.
    */
    get cellTextStyle(): string;
    set cellTextStyle(v: string);
    /**
     * Gets or sets the subtitle text style for the panel.
    */
    get subtitleTextStyle(): string;
    set subtitleTextStyle(v: string);
    /**
     * Gets or sets the base built in theme to use for the checkbox.
    */
    get baseTheme(): BaseControlTheme;
    set baseTheme(v: BaseControlTheme);
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get backgroundColor(): string;
    set backgroundColor(v: string);
    get actualBackgroundColor(): string;
    set actualBackgroundColor(v: string);
    /**
     * Gets or sets the background color for submenus.
    */
    get submenuBackgroundColor(): string;
    set submenuBackgroundColor(v: string);
    get actualSubmenuBackgroundColor(): string;
    set actualSubmenuBackgroundColor(v: string);
    /**
     * Gets or sets the group header background color.
    */
    get groupHeaderBackgroundColor(): string;
    set groupHeaderBackgroundColor(v: string);
    get actualGroupHeaderBackgroundColor(): string;
    set actualGroupHeaderBackgroundColor(v: string);
    /**
     * Gets or sets the separator background color.
    */
    get separatorBackgroundColor(): string;
    set separatorBackgroundColor(v: string);
    get actualSeparatorBackgroundColor(): string;
    set actualSeparatorBackgroundColor(v: string);
    /**
     * Gets or sets the group header separator background color.
    */
    get groupHeaderSeparatorBackgroundColor(): string;
    set groupHeaderSeparatorBackgroundColor(v: string);
    get actualGroupHeaderSeparatorBackgroundColor(): string;
    set actualGroupHeaderSeparatorBackgroundColor(v: string);
    /**
     * Gets or sets the hover background color.
    */
    get hoverBackgroundColor(): string;
    set hoverBackgroundColor(v: string);
    get actualHoverBackgroundColor(): string;
    set actualHoverBackgroundColor(v: string);
    /**
     * Gets or sets the color to use for the text of the component.
    */
    get textColor(): string;
    set textColor(v: string);
    get actualTextColor(): string;
    set actualTextColor(v: string);
    get actualSubtitleTextColor(): string;
    set actualSubtitleTextColor(v: string);
    /**
     * Gets or sets the color to use for the subtitle of the component.
    */
    get subtitleTextColor(): string;
    set subtitleTextColor(v: string);
    /**
     * Gets or sets the color to use for the text in disabled tool actions.
    */
    get disabledTextColor(): string;
    set disabledTextColor(v: string);
    get actualDisabledTextColor(): string;
    set actualDisabledTextColor(v: string);
    /**
     * Gets or sets the text color for group header tool actions.
    */
    get groupHeaderTextColor(): string;
    set groupHeaderTextColor(v: string);
    get actualGroupHeaderTextColor(): string;
    set actualGroupHeaderTextColor(v: string);
    /**
     * Gets or sets the text color for group header subtitle.
    */
    get groupHeaderSubtitleTextColor(): string;
    set groupHeaderSubtitleTextColor(v: string);
    get actualGroupHeaderSubtitleTextColor(): string;
    set actualGroupHeaderSubtitleTextColor(v: string);
    /**
     * Gets or sets the tooltip text color.
    */
    get toolTipTextColor(): string;
    set toolTipTextColor(v: string);
    get actualToolTipTextColor(): string;
    set actualToolTipTextColor(v: string);
    /**
     * Gets or sets the tooltip background color.
    */
    get toolTipBackgroundColor(): string;
    set toolTipBackgroundColor(v: string);
    /**
     * Gets the actual tooltip background color.
    */
    get actualToolTipBackgroundColor(): string;
    set actualToolTipBackgroundColor(v: string);
    /**
     * Gets or sets the tooltip corner radius.
    */
    get toolTipCornerRadius(): number;
    set toolTipCornerRadius(v: number);
    /**
     * Gets the actual tooltip corner radius.
    */
    get actualToolTipCornerRadius(): number;
    set actualToolTipCornerRadius(v: number);
    /**
     * Gets or sets the shadow elevation for the tooltip.
    */
    get toolTipElevation(): number;
    set toolTipElevation(v: number);
    /**
     * Gets the actual shadow elevation used by the tooltip.
    */
    get actualToolTipElevation(): number;
    set actualToolTipElevation(v: number);
    /**
     * Gets or sets the fill color of icons in the ToolPanel.
    */
    get iconFill(): string;
    set iconFill(v: string);
    /**
     * Gets the actual icon fill color.
    */
    get actualIconFill(): string;
    set actualIconFill(v: string);
    /**
     * Gets or sets the stroke color of icons in the ToolPanel.
    */
    get iconStroke(): string;
    set iconStroke(v: string);
    /**
     * Gets the actual icon stroke color.
    */
    get actualIconStroke(): string;
    set actualIconStroke(v: string);
    /**
     * Gets or sets the left padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingLeft(): number;
    set separatorVerticalPaddingLeft(v: number);
    get actualSeparatorVerticalPaddingLeft(): number;
    set actualSeparatorVerticalPaddingLeft(v: number);
    /**
     * Gets or sets the right padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingRight(): number;
    set separatorVerticalPaddingRight(v: number);
    get actualSeparatorVerticalPaddingRight(): number;
    set actualSeparatorVerticalPaddingRight(v: number);
    /**
     * Gets or sets the top padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingTop(): number;
    set separatorVerticalPaddingTop(v: number);
    get actualSeparatorVerticalPaddingTop(): number;
    set actualSeparatorVerticalPaddingTop(v: number);
    /**
     * Gets or sets the bottom padding for separators in the vertical orientation.
    */
    get separatorVerticalPaddingBottom(): number;
    set separatorVerticalPaddingBottom(v: number);
    get actualSeparatorVerticalPaddingBottom(): number;
    set actualSeparatorVerticalPaddingBottom(v: number);
    /**
     * Gets or sets the left padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingLeft(): number;
    set separatorHorizontalPaddingLeft(v: number);
    get actualSeparatorHorizontalPaddingLeft(): number;
    set actualSeparatorHorizontalPaddingLeft(v: number);
    /**
     * Gets or sets the right padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingRight(): number;
    set separatorHorizontalPaddingRight(v: number);
    get actualSeparatorHorizontalPaddingRight(): number;
    set actualSeparatorHorizontalPaddingRight(v: number);
    /**
     * Gets or sets the top padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingTop(): number;
    set separatorHorizontalPaddingTop(v: number);
    get actualSeparatorHorizontalPaddingTop(): number;
    set actualSeparatorHorizontalPaddingTop(v: number);
    /**
     * Gets or sets the bottom padding for separators in the horizontal orientation.
    */
    get separatorHorizontalPaddingBottom(): number;
    set separatorHorizontalPaddingBottom(v: number);
    get actualSeparatorHorizontalPaddingBottom(): number;
    set actualSeparatorHorizontalPaddingBottom(v: number);
    /**
     * Gets or sets the color to use for the background of the component.
    */
    get orientation(): ToolPanelOrientation;
    set orientation(v: ToolPanelOrientation);
    /**
     * Gets or sets the row height for the panel.
    */
    get rowHeight(): number;
    set rowHeight(v: number);
    /**
     * Gets the actual row height used by the panel.
    */
    get actualRowHeight(): number;
    get highlightWidth(): number;
    set highlightWidth(v: number);
    get actualHighlightWidth(): number;
    set actualHighlightWidth(v: number);
    get highlightRadius(): number;
    set highlightRadius(v: number);
    get actualHighlightRadius(): number;
    set actualHighlightRadius(v: number);
    get highlightColor(): string;
    set highlightColor(v: string);
    get actualHighlightColor(): string;
    set actualHighlightColor(v: string);
    /**
     * Gets or sets the stroke color for all icon menu dropdown arrows.
    */
    get menuArrowStroke(): string;
    set menuArrowStroke(v: string);
    /**
     * Gets the actual stroke color for all icon menu dropdown arrows.
    */
    get actualMenuArrowStroke(): string;
    set actualMenuArrowStroke(v: string);
    /**
     * Gets or sets the background color of the radio when in the unchecked state.
    */
    get uncheckedBackgroundColor(): string;
    set uncheckedBackgroundColor(v: string);
    /**
     * Gets the actual background color of the radio when in the unchecked state.
    */
    get actualUncheckedBackgroundColor(): string;
    set actualUncheckedBackgroundColor(v: string);
    /**
     * Gets or sets the background color of the radio when in the checked state.
    */
    get checkedBackgroundColor(): string;
    set checkedBackgroundColor(v: string);
    /**
     * Gets the actual background color of the radio when in the checked state.
    */
    get actualCheckedBackgroundColor(): string;
    set actualCheckedBackgroundColor(v: string);
    /**
     * Gets or sets the border color of the radio when in the unchecked state.
    */
    get uncheckedBorderColor(): string;
    set uncheckedBorderColor(v: string);
    /**
     * Gets the actual border color of the radio when in the unchecked state.
    */
    get actualUncheckedBorderColor(): string;
    set actualUncheckedBorderColor(v: string);
    /**
     * Gets or sets the border color of the radio when in the checked state.
    */
    get checkedBorderColor(): string;
    set checkedBorderColor(v: string);
    /**
     * Gets the actual border color of the radio when in the checked state.
    */
    get actualCheckedBorderColor(): string;
    set actualCheckedBorderColor(v: string);
    /**
     * Gets or sets the dropdown delay time in milliseconds.
    */
    get dropdownDelay(): number;
    set dropdownDelay(v: number);
    /**
     * Gets the actual dropdown delay.
    */
    get actualDropdownDelay(): number;
    set actualDropdownDelay(v: number);
    /**
     * Gets or sets the mode used when displaying nested actions.
    */
    get nestedActionMode(): NestedActionMode;
    set nestedActionMode(v: NestedActionMode);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    refresh(): void;
    getDesiredSize(): IgSize;
    /**
     * Forces any open sub menus to close.
    
    */
    closeSubmenus(): void;
    exportVisualData(): any;
    exportSerializedVisualData(): string;
    private _contentRefreshed;
    private _contentRefreshed_wrapped;
    get contentRefreshed(): (s: IgrToolPanel, e: IgrToolPanelContentRefreshedEventArgs) => void;
    set contentRefreshed(ev: (s: IgrToolPanel, e: IgrToolPanelContentRefreshedEventArgs) => void);
    private _onCommand;
    private _onCommand_wrapped;
    get onCommand(): (s: IgrToolPanel, e: IgrToolCommandEventArgs) => void;
    set onCommand(ev: (s: IgrToolPanel, e: IgrToolCommandEventArgs) => void);
}
export interface IIgrToolPanelProps {
    width?: string;
    height?: string;
    children?: React.ReactNode;
    actions?: IgrToolActionCollection;
    /**
 * Gets or sets if the tool actions should display their submenus on mouse hover.
*/
    showOnHover?: boolean | string;
    /**
     * Gets or sets the text style for the panel.
    */
    cellTextStyle?: string;
    /**
     * Gets or sets the subtitle text style for the panel.
    */
    subtitleTextStyle?: string;
    /**
     * Gets or sets the base built in theme to use for the checkbox.
    */
    baseTheme?: BaseControlTheme | string;
    /**
     * Gets or sets the color to use for the background of the component.
    */
    backgroundColor?: string;
    actualBackgroundColor?: string;
    /**
     * Gets or sets the background color for submenus.
    */
    submenuBackgroundColor?: string;
    actualSubmenuBackgroundColor?: string;
    /**
     * Gets or sets the group header background color.
    */
    groupHeaderBackgroundColor?: string;
    actualGroupHeaderBackgroundColor?: string;
    /**
     * Gets or sets the separator background color.
    */
    separatorBackgroundColor?: string;
    actualSeparatorBackgroundColor?: string;
    /**
     * Gets or sets the group header separator background color.
    */
    groupHeaderSeparatorBackgroundColor?: string;
    actualGroupHeaderSeparatorBackgroundColor?: string;
    /**
     * Gets or sets the hover background color.
    */
    hoverBackgroundColor?: string;
    actualHoverBackgroundColor?: string;
    /**
     * Gets or sets the color to use for the text of the component.
    */
    textColor?: string;
    actualTextColor?: string;
    actualSubtitleTextColor?: string;
    /**
     * Gets or sets the color to use for the subtitle of the component.
    */
    subtitleTextColor?: string;
    /**
     * Gets or sets the color to use for the text in disabled tool actions.
    */
    disabledTextColor?: string;
    actualDisabledTextColor?: string;
    /**
     * Gets or sets the text color for group header tool actions.
    */
    groupHeaderTextColor?: string;
    actualGroupHeaderTextColor?: string;
    /**
     * Gets or sets the text color for group header subtitle.
    */
    groupHeaderSubtitleTextColor?: string;
    actualGroupHeaderSubtitleTextColor?: string;
    /**
     * Gets or sets the tooltip text color.
    */
    toolTipTextColor?: string;
    actualToolTipTextColor?: string;
    /**
     * Gets or sets the tooltip background color.
    */
    toolTipBackgroundColor?: string;
    /**
     * Gets the actual tooltip background color.
    */
    actualToolTipBackgroundColor?: string;
    /**
     * Gets or sets the tooltip corner radius.
    */
    toolTipCornerRadius?: number | string;
    /**
     * Gets the actual tooltip corner radius.
    */
    actualToolTipCornerRadius?: number | string;
    /**
     * Gets or sets the shadow elevation for the tooltip.
    */
    toolTipElevation?: number | string;
    /**
     * Gets the actual shadow elevation used by the tooltip.
    */
    actualToolTipElevation?: number | string;
    /**
     * Gets or sets the fill color of icons in the ToolPanel.
    */
    iconFill?: string;
    /**
     * Gets the actual icon fill color.
    */
    actualIconFill?: string;
    /**
     * Gets or sets the stroke color of icons in the ToolPanel.
    */
    iconStroke?: string;
    /**
     * Gets the actual icon stroke color.
    */
    actualIconStroke?: string;
    /**
     * Gets or sets the left padding for separators in the vertical orientation.
    */
    separatorVerticalPaddingLeft?: number | string;
    actualSeparatorVerticalPaddingLeft?: number | string;
    /**
     * Gets or sets the right padding for separators in the vertical orientation.
    */
    separatorVerticalPaddingRight?: number | string;
    actualSeparatorVerticalPaddingRight?: number | string;
    /**
     * Gets or sets the top padding for separators in the vertical orientation.
    */
    separatorVerticalPaddingTop?: number | string;
    actualSeparatorVerticalPaddingTop?: number | string;
    /**
     * Gets or sets the bottom padding for separators in the vertical orientation.
    */
    separatorVerticalPaddingBottom?: number | string;
    actualSeparatorVerticalPaddingBottom?: number | string;
    /**
     * Gets or sets the left padding for separators in the horizontal orientation.
    */
    separatorHorizontalPaddingLeft?: number | string;
    actualSeparatorHorizontalPaddingLeft?: number | string;
    /**
     * Gets or sets the right padding for separators in the horizontal orientation.
    */
    separatorHorizontalPaddingRight?: number | string;
    actualSeparatorHorizontalPaddingRight?: number | string;
    /**
     * Gets or sets the top padding for separators in the horizontal orientation.
    */
    separatorHorizontalPaddingTop?: number | string;
    actualSeparatorHorizontalPaddingTop?: number | string;
    /**
     * Gets or sets the bottom padding for separators in the horizontal orientation.
    */
    separatorHorizontalPaddingBottom?: number | string;
    actualSeparatorHorizontalPaddingBottom?: number | string;
    /**
     * Gets or sets the color to use for the background of the component.
    */
    orientation?: ToolPanelOrientation | string;
    /**
     * Gets or sets the row height for the panel.
    */
    rowHeight?: number | string;
    highlightWidth?: number | string;
    actualHighlightWidth?: number | string;
    highlightRadius?: number | string;
    actualHighlightRadius?: number | string;
    highlightColor?: string;
    actualHighlightColor?: string;
    /**
     * Gets or sets the stroke color for all icon menu dropdown arrows.
    */
    menuArrowStroke?: string;
    /**
     * Gets the actual stroke color for all icon menu dropdown arrows.
    */
    actualMenuArrowStroke?: string;
    /**
     * Gets or sets the background color of the radio when in the unchecked state.
    */
    uncheckedBackgroundColor?: string;
    /**
     * Gets the actual background color of the radio when in the unchecked state.
    */
    actualUncheckedBackgroundColor?: string;
    /**
     * Gets or sets the background color of the radio when in the checked state.
    */
    checkedBackgroundColor?: string;
    /**
     * Gets the actual background color of the radio when in the checked state.
    */
    actualCheckedBackgroundColor?: string;
    /**
     * Gets or sets the border color of the radio when in the unchecked state.
    */
    uncheckedBorderColor?: string;
    /**
     * Gets the actual border color of the radio when in the unchecked state.
    */
    actualUncheckedBorderColor?: string;
    /**
     * Gets or sets the border color of the radio when in the checked state.
    */
    checkedBorderColor?: string;
    /**
     * Gets the actual border color of the radio when in the checked state.
    */
    actualCheckedBorderColor?: string;
    /**
     * Gets or sets the dropdown delay time in milliseconds.
    */
    dropdownDelay?: number | string;
    /**
     * Gets the actual dropdown delay.
    */
    actualDropdownDelay?: number | string;
    /**
     * Gets or sets the mode used when displaying nested actions.
    */
    nestedActionMode?: NestedActionMode | string;
    contentRefreshed?: (s: IgrToolPanel, e: IgrToolPanelContentRefreshedEventArgs) => void;
    onCommand?: (s: IgrToolPanel, e: IgrToolCommandEventArgs) => void;
}
